@@ -1,7 +1,7 @@
 /**
 * +----------------------------------------------------------------------+
 * | This file is part of Samplecat. http://ayyi.github.io/samplecat/     |
-* | copyright (C) 2007-2020 Tim Orford <tim@orford.org>                  |
+* | copyright (C) 2007-2021 Tim Orford <tim@orford.org>                  |
 * +----------------------------------------------------------------------+
 * | This program is free software; you can redistribute it and/or modify |
 * | it under the terms of the GNU General Public License version 3       |
@@ -16,13 +16,15 @@
 #include "samplecat.h"
 #include "utils/ayyi_utils.h"
 #include "waveform/actor.h"
-#include "yaml_utils.h"
+#include "yaml/load.h"
+#include "yaml/save.h"
 #include "application.h"
 #include "behaviours/state.h"
 #include "behaviours/panel.h"
 #include "layout.h"
 
 typedef AGlActorClass* (get_class)();
+
 get_class dock_v_get_class, dock_h_get_class, scrollable_view_get_class, list_view_get_class, files_view_get_class, directories_view_get_class, inspector_view_get_class, search_view_get_class, filters_view_get_class, player_view_get_class, scrollbar_view_get_class, button_get_class
 #ifdef HAVE_FFTW3
 	, spectrogram_view_get_class
@@ -33,22 +35,6 @@ get_class dock_v_get_class, dock_h_get_class, scrollable_view_get_class, list_vi
 
 GHashTable* agl_actor_registry; // maps className to AGlActorClass
 
-#define PLAIN_IMPLICIT true
-
-#define end_map_(E) \
-		if(!yaml_mapping_end_event_initialize(E)) goto error; \
-		if(!yaml_emitter_emit(&emitter, E)) goto error;
-
-#define map_open_(E, A) \
-		if(!yaml_scalar_event_initialize(E, NULL, str_tag, (guchar*)A, -1, PLAIN_IMPLICIT, 0, YAML_PLAIN_SCALAR_STYLE)) goto error; \
-		if(!yaml_emitter_emit(&emitter, E)) goto error; \
-		if(!yaml_mapping_start_event_initialize(E, NULL, map_tag, 1, YAML_BLOCK_MAPPING_STYLE)) goto error; \
-		if(!yaml_emitter_emit(&emitter, E)) goto error; \
-
-#define EMIT(A) \
-	if(!A) goto error; \
-	if(!yaml_emitter_emit(&emitter, &event)) goto error;
-
 
 static void
 agl_actor_register_class (const char* name, AGlActorClass* class)
@@ -59,16 +45,16 @@ agl_actor_register_class (const char* name, AGlActorClass* class)
 }
 
 
-static AGliPt
-config_load_point (yaml_parser_t* parser, yaml_event_t* event)
+static bool
+config_load_point (yaml_parser_t* parser, gpointer _pt)
 {
-	AGliPt p = {0,};
+	AGliPt* pt = _pt;
 
-	void load_integers(yaml_parser_t* parser, AGliPt* p)
+	void load_integers (yaml_parser_t* parser, AGliPt* p)
 	{
 		yaml_event_t event;
-		int i; for(i=0;i<2;i++){
-			if(yaml_parser_parse(parser, &event)){
+		for (int i=0;i<2;i++) {
+			if (yaml_parser_parse(parser, &event)) {
 				switch (event.type) {
 					case YAML_SCALAR_EVENT:
 						;int* a = i ? &p->y : &p->x;
@@ -78,26 +64,62 @@ config_load_point (yaml_parser_t* parser, yaml_event_t* event)
 						break;
 				}
 			}
+			yaml_event_delete(&event);
+		}
+	}
+
+	yaml_event_t event;
+	while (yaml_parser_parse(parser, &event)) {
+		switch (event.type) {
+			case YAML_SEQUENCE_START_EVENT:
+				load_integers(parser, pt);
+				break;
+			case YAML_SEQUENCE_END_EVENT:
+				yaml_event_delete(&event);
+				return true;
+			case YAML_SCALAR_EVENT:
+				pwarn("expected array start but got scalar");
+				break;
+			default:
+				pwarn("expected array start %i", event.type);
 		}
 		yaml_event_delete(&event);
 	}
+	pwarn("sequence end not found");
 
-	while(yaml_parser_parse(parser, event)){
-		switch (event->type) {
-			case YAML_SEQUENCE_START_EVENT:
-				load_integers(parser, &p);
-				break;
-			case YAML_SEQUENCE_END_EVENT:
-				return p;
-			case YAML_SCALAR_EVENT:
-				gwarn("expected array start but got scalar");
-				break;
-			default:
-				gwarn("expected array start %i", event->type);
-		}
-	}
-	gwarn("?");
-	return p;
+	return true;
+}
+
+
+static bool
+config_load_size (yaml_parser_t* parser, const yaml_event_t* _, gpointer _actor)
+{
+	AGlActor* actor = _actor;
+
+	AGliPt pt = {0};
+	config_load_point(parser, &pt);
+
+	actor->region.x2 = actor->region.x1 + pt.x;
+	actor->region.y2 = actor->region.y1 + pt.y;
+
+	return true;
+}
+
+
+static bool
+config_load_position (yaml_parser_t* parser, const yaml_event_t* _, gpointer _actor)
+{
+	AGlActor* actor = _actor;
+
+	AGliPt pt = {0};
+	config_load_point(parser, &pt);
+
+	actor->region.x1 = pt.x;
+	actor->region.y1 = pt.y;
+	actor->region.x2 += pt.x;
+	actor->region.y2 += pt.y;
+
+	return true;
 }
 
 
@@ -131,160 +153,244 @@ end_wrapper (yaml_parser_t* parser)
 }
 #endif
 
-#define get_expected_event(parser, event, EVENT_TYPE) \
-	if(!yaml_parser_parse(parser, event)) return false; \
-	if((event)->type != EVENT_TYPE) return false;
 
 static bool
-load_size_req (yaml_parser_t* parser, yaml_event_t* event, AGlActor* actor)
+load_size_req (yaml_parser_t* parser, const yaml_event_t* _, gpointer _actor)
 {
-	if(actor->class == panel_view_get_class() || actor->class == dock_v_get_class() || actor->class == dock_h_get_class()){
-		get_expected_event(parser, event, YAML_MAPPING_START_EVENT);
-		int i = 0; for(;yaml_parser_parse(parser, event) && i < 20; i++){
-			switch(event->type){
+	AGlActor* actor = _actor;
+
+	if (actor->class == panel_view_get_class() || actor->class == dock_v_get_class() || actor->class == dock_h_get_class()) {
+		yaml_event_t event;
+		get_expected_event(parser, &event, YAML_MAPPING_START_EVENT);
+		yaml_event_delete(&event);
+
+		for (int i = 0; yaml_parser_parse(parser, &event) && i < 20; i++) {
+			switch (event.type) {
 				case YAML_SCALAR_EVENT:
 					{
-						char* key = (char*)event->data.scalar.value;
-						if(!strcmp(key, "min")){
-							((PanelView*)actor)->size_req.min = config_load_point(parser, event);
-						}else if(!strcmp(key, "preferred")){
-							((PanelView*)actor)->size_req.preferred = config_load_point(parser, event);
-						}else if(!strcmp(key, "max")){
-							((PanelView*)actor)->size_req.max = config_load_point(parser, event);
+						char* key = (char*)event.data.scalar.value;
+						if (!strcmp(key, "min")) {
+							config_load_point(parser, &((PanelView*)actor)->size_req.min);
+						} else if (!strcmp(key, "preferred")) {
+							config_load_point(parser, &((PanelView*)actor)->size_req.preferred);
+						} else if (!strcmp(key, "max")) {
+							config_load_point(parser, &((PanelView*)actor)->size_req.max);
 						}
 					}
 					break;
 				case YAML_MAPPING_END_EVENT:
+					yaml_event_delete(&event);
 					return true;
 				default:
+					yaml_event_delete(&event);
 					return false;
 			}
+			yaml_event_delete(&event);
 		}
 	}
+	else pwarn("no class match: class=%p", actor->class);
+
 	return false;
 }
 
 
+#define STACK_SIZE 32
+
+typedef struct {
+	AGlActor* items[STACK_SIZE];
+	int       sp;
+	char      name[64];
+} Stack;
+
+#define STACK_PUSH(ACTOR) ({if(stack->sp >= STACK_SIZE) return FALSE; stack->items[++stack->sp] = ACTOR;})
+#define STACK_POP() ({AGlActor* a = stack->items[stack->sp]; stack->items[stack->sp--] = NULL; a;})
+
+
 static bool
-config_load_window_yaml (yaml_parser_t* parser, yaml_event_t* event)
+type_handler (yaml_parser_t* parser, const yaml_event_t* _event, gpointer _stack)
 {
-	// At this point in the parsing, we have just found a "ROOT" map. First event should be a YAML_SCALAR_EVENT...
+	Stack* stack = _stack;
 
-	#define STACK_SIZE 32
-	AGlActor* stack[STACK_SIZE] = {0,};
-	int sp = -1;
-	#define STACK_PUSH(ACTOR) ({if(sp >= STACK_SIZE) return FALSE; stack[++sp] = ACTOR;})
-	#define STACK_POP() ({AGlActor* a = stack[sp]; stack[sp--] = NULL; a;})
+	yaml_event_t event;
+	get_expected_event(parser, &event, YAML_SCALAR_EVENT);
 
-	//if(!start_wrapper(parser, "ROOT")) return FALSE;
+	if (!strcmp((char*)event.data.scalar.value, "ROOT")) {
+		STACK_PUSH((AGlActor*)app->scene);
+	} else if (!strcmp((char*)event.data.scalar.value, "Waveform")) {
+		STACK_PUSH ((AGlActor*)wf_context_add_new_actor (app->wfc, NULL));
+	} else {
+		AGlActorClass* c = g_hash_table_lookup(agl_actor_registry, event.data.scalar.value);
+		if (c) {
+			if (c->new) {
+				STACK_PUSH(c->new(NULL));
+				stack->items[stack->sp]->name = g_strdup(stack->name);
+			}
+		} else {
+			pwarn("type not found: %s", event.data.scalar.value);
+		}
+	}
 
+	yaml_event_delete(&event);
+
+	return true;
+}
+
+
+static bool
+generic_handler (yaml_parser_t* parser, const yaml_event_t* event, gpointer _stack)
+{
+	char* key = (char*)event->data.scalar.value;
+
+	Stack* stack = _stack;
+	if(stack->sp < 0) return false;
+	AGlActor* actor = stack->items[stack->sp];
+	g_return_val_if_fail(actor, false);
+
+	if(state_has_parameter(actor, key)){
+		yaml_event_t event2;
+		get_expected_event(parser, &event2, YAML_SCALAR_EVENT);
+
+		state_set_named_parameter(actor, key, (char*)event2.data.scalar.value);
+		yaml_event_delete(&event2);
+	}
+
+	return true;
+}
+
+
+static bool
+handle_scalar_events (yaml_parser_t* parser, yaml_event_t* event, Stack* stack)
+{
+	return handle_scalar_event(parser, event, (YamlHandler[]){
+		{"type", type_handler, stack},
+		{"size", config_load_size, stack->items[stack->sp]},
+		{"position", config_load_position, stack->items[stack->sp]},
+		{"size-req", load_size_req, stack->items[stack->sp]},
+		{NULL, generic_handler, stack},
+		{NULL}
+	});
+}
+
+
+/*
+ *  The previous event should be YAML_MAPPING_START_EVENT
+ */
+static bool
+add_node (yaml_parser_t* parser, char* node_name, Stack* stack)
+{
+	g_strlcpy(stack->name, node_name, 64);
 	char key[64] = {0,};
-	char name[64] = {0,};
-	int depth = 0;
-	while(yaml_parser_parse(parser, event)){
-		switch (event->type) {
+
+	yaml_event_t event;
+	while (yaml_parser_parse(parser, &event)) {
+		switch (event.type) {
 			case YAML_SCALAR_EVENT:
-				dbg(2, "YAML_SCALAR_EVENT: value='%s' %i plain=%i style=%i", event->data.scalar.value, event->data.scalar.length, event->data.scalar.plain_implicit, event->data.scalar.style);
+				dbg(2, "YAML_SCALAR_EVENT: value='%s' %lu plain=%i style=%i", event.data.scalar.value, event.data.scalar.length, event.data.scalar.plain_implicit, event.data.scalar.style);
 
-				if(!key[0]){
-					// 1st half of a pair
-					g_strlcpy(key, (char*)event->data.scalar.value, 64);
+				g_strlcpy(key, (char*)event.data.scalar.value, 64);
 
-					if(!strcmp(key, "size")){
-						AGliPt p = config_load_point(parser, event);
-						stack[sp]->region.x2 = stack[sp]->region.x1 + p.x;
-						stack[sp]->region.y2 = stack[sp]->region.y1 + p.y;
-						key[0] = '\0';
-					} else if(!strcmp(key, "position")){
-						AGliPt p = config_load_point(parser, event);
-						stack[sp]->region.x1 = p.x;
-						stack[sp]->region.y1 = p.y;
-						stack[sp]->region.x2 += p.x;
-						stack[sp]->region.y2 += p.y;
-						key[0] = '\0';
-					} else if(!strcmp(key, "size-req")){
-						load_size_req(parser, event, stack[sp]);
-						key[0] = '\0';
-					}
-				}else{
-					// 2nd half of a pair
-					if(!strcmp(key, "type")){
-						dbg(2, "found actor: %s=%s", key, event->data.scalar.value);
-						if(!strcmp((char*)event->data.scalar.value, "ROOT")){
-							STACK_PUSH((AGlActor*)app->scene);
-						}else if(!strcmp((char*)event->data.scalar.value, "Waveform")){
-							STACK_PUSH((AGlActor*)wf_canvas_add_new_actor(app->wfc, NULL));
-						}else{
-							AGlActorClass* c = g_hash_table_lookup(agl_actor_registry, event->data.scalar.value);
-							if(c){
-								if(c->new){
-									STACK_PUSH(c->new(NULL));
-									stack[sp]->name = g_strdup(name);
-								}
-							}else{
-								gwarn("             type not found: %s", event->data.scalar.value);
-							}
-						}
-					}else{
-						if(!state_set_named_parameter(stack[sp], key, (char*)event->data.scalar.value)){
-							dbg(0, "  ignoring: %s=%s", key, event->data.scalar.value);
-						}
-					}
-					key[0] = '\0';
-				}
+				handle_scalar_events(parser, &event, stack);
 				break;
 			case YAML_MAPPING_START_EVENT:
-				depth++;
-				if(key[0]){
-					g_strlcpy(name, key, 64);
+				if (key[0]) {
+					add_node(parser, key, stack);
 					key[0] = '\0';
 				}
-				else gwarn("mapping event has no name. depth=%i", depth);
 				break;
 			case YAML_MAPPING_END_EVENT:
-				dbg(2, "<-");
-				if(sp > 0){
-					dbg(2, "<- sp=%i: adding '%s' to '%s'", sp, stack[sp] ? stack[sp]->name : NULL, stack[sp - 1] ? stack[sp - 1]->name : NULL);
-					AGlActor* actor = stack[sp];
-					AGlActor* parent = stack[sp - 1];
+				if (stack->sp > 0) {
+					AGlActor* actor = stack->items[stack->sp];
+					AGlActor* parent = stack->items[stack->sp - 1];
+					dbg(2, "<- sp=%i: adding '%s' to '%s'", stack->sp, actor ? actor->name : NULL, parent ? parent->name : NULL);
 					AGlActorClass* parent_class = parent->class;
-					if(parent_class == dock_v_get_class() || parent_class == dock_h_get_class()){
-						dock_v_add_panel((DockVView*)stack[sp], STACK_POP());
+					if (parent_class == dock_v_get_class() || parent_class == dock_h_get_class()) {
+						dock_v_add_panel((DockVView*)parent, STACK_POP());
 						{
-							if(actor->class == panel_view_get_class()){
+							if (actor->class == panel_view_get_class()) {
 								g_return_val_if_fail(g_list_length(actor->children) == 1, false);
 								AGlActor* child = (AGlActor*)actor->children->data;
 								char* name = child->name;
-								if(strcmp(name, "Search") && strcmp(name, "Spectrogram") && strcmp(name, "Filters") && strcmp(name, "Tabs") && strcmp(name, "Waveform")){
-									if(!strcmp(name, "Scrollable")){
+								if (strcmp(name, "Search") && strcmp(name, "Spectrogram") && strcmp(name, "Filters") && strcmp(name, "Tabs") && strcmp(name, "Waveform")) {
+									if (!strcmp(name, "Scrollable")) {
 										name = ((AGlActor*)child->children->data)->name;
 									}
 									((PanelView*)actor)->title = name;
 								}
 							}
 						}
-					}else if(parent_class == tabs_view_get_class()){
+					} else if (parent_class == tabs_view_get_class()) {
 						tabs_view__add_tab((TabsView*)parent, actor->name, STACK_POP());
-					}else{
-						agl_actor__add_child(stack[sp], STACK_POP());
+					} else {
+						agl_actor__add_child(parent, STACK_POP());
 					}
 					g_signal_emit_by_name(app, "actor-added", actor);
 				}
 
-				depth--;
-				if(depth < 0){ dbg(2, "done"); return true; }
+				yaml_event_delete(&event);
+				return true;
 				break;
+			case YAML_NO_EVENT:
 			case YAML_SEQUENCE_START_EVENT:
 			case YAML_SEQUENCE_END_EVENT:
 			default:
-				gwarn("unexpected parser event type: %i", event->type);
+				pwarn("unexpected parser event type: %i", event.type);
+				goto fail;
+		}
+
+		yaml_event_delete(&event);
+	}
+
+	return false;
+
+  fail:
+	yaml_event_delete(&event);
+	return false;
+}
+
+
+static bool
+window_handler (yaml_parser_t* parser, const yaml_event_t* _event, char* _key, gpointer _)
+{
+	// At this point in the parsing, we have just found a "ROOT" map. First event should be a YAML_SCALAR_EVENT...
+
+	Stack stack = {.sp = -1};
+
+	//if(!start_wrapper(parser, "ROOT")) return FALSE;
+
+	char key[64] = {0,};
+	yaml_event_t event;
+	while (yaml_parser_parse(parser, &event)) {
+		switch (event.type) {
+			case YAML_SCALAR_EVENT:
+				dbg(2, "YAML_SCALAR_EVENT: value='%s' %lu plain=%i style=%i", event.data.scalar.value, event.data.scalar.length, event.data.scalar.plain_implicit, event.data.scalar.style);
+
+				g_strlcpy(key, (char*)event.data.scalar.value, 64);
+
+				handle_scalar_events(parser, &event, &stack);
+				break;
+			case YAML_MAPPING_START_EVENT:
+				if (key[0]) {
+					add_node(parser, key, &stack);
+					key[0] = '\0';
+				}
+				break;
+			case YAML_MAPPING_END_EVENT:
+				return true;
+			case YAML_NO_EVENT:
+				pwarn("EOF");
+				yaml_event_delete(&event);
+				return false;
+			case YAML_SEQUENCE_START_EVENT:
+			case YAML_SEQUENCE_END_EVENT:
+			default:
+				pwarn("unexpected parser event type: %i", event.type);
 				break;
 		}
+		yaml_event_delete(&event);
 	}
 
 	//if(!end_wrapper(parser)) return FALSE;
 
-	gwarn("unexpected end");
 	return false;
 }
 
@@ -297,38 +403,16 @@ layout_set_size (gpointer data)
 }
 
 
-static void
-config_load_windows_yaml (yaml_parser_t* parser, yaml_event_t* event, gpointer user_data)
+static bool
+config_load_windows (yaml_parser_t* parser, const yaml_event_t* _, gpointer user_data)
 {
-	// TODO use start_wrapper ?
-
-	char key[64] = {0,};
-	int depth = 0;
-	int i = 0;
-	while(yaml_parser_parse(parser, event) && i++ < 2){
-		switch (event->type) {
-			case YAML_SCALAR_EVENT:
-				dbg(2, "YAML_SCALAR_EVENT: value='%s' %i plain=%i style=%i", event->data.scalar.value, event->data.scalar.length, event->data.scalar.plain_implicit, event->data.scalar.style);
-
-				if(!key[0]){
-					// first half of a pair
-					g_strlcpy(key, (char*)event->data.scalar.value, 64);
-				}else{
-					gwarn("unexpected");
-				}
-				break;
-			case YAML_MAPPING_START_EVENT:
-				depth++;
-				if(key[0]){
-					if(strcmp(key, "window")) gwarn("expected 'window'. no other valid sections.");
-
-					config_load_window_yaml(parser, event);
-				}
-				break;
-			default:
-				break;
-		}
-	}
+	load_mapping(parser,
+		NULL,
+		(YamlMappingHandler[]){
+			{"window", window_handler}
+		},
+		user_data
+	);
 
 #if 0
 #ifdef DEBUG
@@ -366,57 +450,47 @@ config_load_windows_yaml (yaml_parser_t* parser, yaml_event_t* event, gpointer u
 #endif
 #endif
 
-	if(!g_list_length(((AGlActor*)app->scene)->children)) return gwarn("layout did not load - pls check config file");
+	if(!g_list_length(((AGlActor*)app->scene)->children)){
+		pwarn("layout did not load - pls check config file");
+		return false;
+	}
 
 	g_idle_add(layout_set_size, NULL);
+
+	return true;
 }
 
 
 static FILE*
 open_settings_file ()
 {
+	g_autofree char* cwd = g_get_current_dir();
 	char* paths[] = {
 		g_strdup_printf("%s/.config/" PACKAGE, g_get_home_dir()),
 		g_build_filename(PACKAGE_DATA_DIR "/" PACKAGE, NULL),
-		g_build_filename(g_get_current_dir(), NULL)
+		g_build_filename(cwd, NULL),
+		g_build_filename(cwd, "experimental/gl-app", NULL)
 	};
 
 	FILE* fp;
-	int i; for(i=0;i<G_N_ELEMENTS(paths);i++){
-		char* filename = g_strdup_printf("%s/"PACKAGE".yaml", paths[i]);
+	for (int i=0; i<G_N_ELEMENTS(paths); i++) {
+		g_autofree char* filename = g_strdup_printf("%s/"PACKAGE".yaml", paths[i]);
 		fp = fopen(filename, "rb");
-		g_free(filename);
-		if(fp) break;
+		if (fp) {
+			dbg(1, "using: %s", filename);
+			break;
+		}
 	}
-	if(!fp){
+	if (!fp) {
 		fprintf(stderr, "unable to load config file %s/"PACKAGE".yaml\n", paths[0]);
 	}
-	for(i=0;i<G_N_ELEMENTS(paths);i++){
+	for (int i=0;i<G_N_ELEMENTS(paths);i++) {
 		g_free(paths[i]);
 	}
 	return fp;
 }
 
 
-static bool
-find_event (yaml_parser_t* parser, yaml_event_t* event, const char* name)
-{
-	bool found = false;
-	while(!found && yaml_parser_parse(parser, event)){
-		switch (event->type) {
-			case YAML_SCALAR_EVENT:
-				if(!strcmp((char*)event->data.scalar.value, "size")){
-					found = true;
-				}
-				break;
-			default:
-				break;
-		}
-	}
-	return found;
-}
-
-
 AGliPt
 get_window_size_from_settings ()
 {
@@ -425,14 +499,15 @@ get_window_size_from_settings ()
 	yaml_parser_t parser; yaml_parser_initialize(&parser);
 
 	FILE* fp = open_settings_file();
-	if(fp){
+	if (fp) {
 		yaml_parser_set_input_file(&parser, fp);
 
-		yaml_event_t event;
-		if(find_event(&parser, &event, "size")){
-			size = config_load_point(&parser, &event);
+		yaml_event_t e;
+		yaml_event_t* event = &e;
+		if (find_event(&parser, &event, "size")) {
+			config_load_point(&parser, &size);
+			yaml_event_delete(event);
 		}
-		yaml_event_delete(&event);
 
 		yaml_parser_delete(&parser);
 		fclose(fp);
@@ -455,7 +530,6 @@ load_settings ()
 		agl_actor_register_class("Dock H", dock_h_get_class());
 		agl_actor_register_class("Dock V", dock_v_get_class());
 		agl_actor_register_class("Panel", panel_view_get_class());
-		agl_actor_register_class("Scrollable", scrollable_view_get_class());
 		agl_actor_register_class("Dirs", directories_view_get_class());
 		agl_actor_register_class("Inspector", inspector_view_get_class());
 		agl_actor_register_class("Search", search_view_get_class());
@@ -479,15 +553,16 @@ load_settings ()
 		agl_actor_class__add_behaviour(wf_actor_get_class(), panel_get_class());
 	}
 
-	yaml_parser_t parser; yaml_parser_initialize(&parser);
-
 	FILE* fp = open_settings_file();
-	if(!fp) return false;
 
-	return yaml_load(fp, (YamlHandler[]){
-		{"windows", config_load_windows_yaml},
+	bool ret = fp && yaml_load(fp, (YamlHandler[]){
+		{"windows", config_load_windows},
 		{NULL}
 	});
+
+	if(fp) fclose(fp);
+
+	return ret;
 }
 
 
@@ -496,11 +571,11 @@ save_settings ()
 {
 	PF;
 
-	if(!yaml_emitter_initialize(&emitter)){ gerr("failed to initialise yaml writer."); return false; }
+	if (!yaml_emitter_initialize(&emitter)) { gerr("failed to initialise yaml writer."); return false; }
 
 	char* tmp = g_strdup_printf("%s/samplecat.yaml", g_get_tmp_dir());
 	FILE* fp = fopen(tmp, "wb");
-	if(!fp){
+	if (!fp) {
 		printf("cannot open config file for writing (%s)\n", app->config_ctx.filename);
 		return FALSE;
 	}
@@ -509,62 +584,63 @@ save_settings ()
 	yaml_emitter_set_canonical(&emitter, false);
 
 	yaml_event_t event;
-	EMIT(yaml_stream_start_event_initialize(&event, YAML_UTF8_ENCODING));
-	EMIT(yaml_document_start_event_initialize(&event, NULL, NULL, NULL, 0));
-	EMIT(yaml_mapping_start_event_initialize(&event, NULL, (guchar*)"tag:yaml.org,2002:map", 1, YAML_BLOCK_MAPPING_STYLE));
+	EMIT_(yaml_stream_start_event_initialize(&event, YAML_UTF8_ENCODING));
+	EMIT_(yaml_document_start_event_initialize(&event, NULL, NULL, NULL, 0));
+	EMIT_(yaml_mapping_start_event_initialize(&event, NULL, (guchar*)"tag:yaml.org,2002:map", 1, YAML_BLOCK_MAPPING_STYLE));
 
 	char value[256];
 	snprintf(value, 255, "0x%08x", 0xff00ff00);
-	if(!yaml_add_key_value_pair("test_colour", value)) goto error;
+	if (!yaml_add_key_value_pair("test_colour", value)) goto error;
 
 	bool add_child (yaml_event_t* event, AGlActor* actor)
 	{
 		AGlActorClass* c = actor->class;
-		g_return_val_if_fail(c, false);
-		if(c != scrollbar_view_get_class() && c != button_get_class()){
+		if (!c) return true; // It is not an error for an actor to not have a class. It will not be saved.
+
+		if (c != scrollbar_view_get_class() && c != button_get_class() && c != &default_actor_class) {
 			g_return_val_if_fail(actor->name, false);
 
-			map_open_(event, actor->name);
+			map_open(event, actor->name);
 
-			if(!yaml_add_key_value_pair("type", c->name)) goto error;
+			if (!yaml_add_key_value_pair("type", c->name)) goto error;
 
 			bool is_panel_child = actor->parent && actor->parent->class == panel_view_get_class();
 
-			if(!is_panel_child){
+			if (!is_panel_child) {
 				int vals1[2] = {actor->region.x1, actor->region.y1};
-				if(vals1[0] || vals1[1]){
+				if (vals1[0] || vals1[1]) {
 					yaml_add_key_value_pair_array("position", vals1, 2);
 				}
 				int vals2[2] = {agl_actor__width(actor), agl_actor__height(actor)};
 				yaml_add_key_value_pair_array("size", vals2, 2);
 			}
 
-			if(actor->class == panel_view_get_class() || actor->class == dock_v_get_class() || actor->class == dock_h_get_class()){
+			if (actor->class == panel_view_get_class() || actor->class == dock_v_get_class() || actor->class == dock_h_get_class()) {
 				PanelView* panel = (PanelView*)actor;
 				bool b[3] = {
 					panel->size_req.min.x > -1 || panel->size_req.min.y > -1,
 					panel->size_req.preferred.x > -1 || panel->size_req.preferred.y > -1,
 					panel->size_req.max.x > -1 || panel->size_req.max.y > -1
 				};
-				if(b[0] || b[1] || b[2]){
-					map_open_(event, "size-req");
-					if(b[0])
+				if (b[0] || b[1] || b[2]) {
+					map_open(event, "size-req");
+					if (b[0])
 						if(!yaml_add_key_value_pair_pt("min", &panel->size_req.min)) goto error;
-					if(b[1])
+					if (b[1])
 						if(!yaml_add_key_value_pair_pt("preferred", &panel->size_req.preferred)) goto error;
-					if(b[2])
+					if (b[2])
 						if(!yaml_add_key_value_pair_pt("max", &panel->size_req.max)) goto error;
-					end_map_(event);
+					end_map(event);
 				}
 			}
 
-			StateBehaviour* b = (StateBehaviour*)agl_actor__get_behaviour(actor, state_get_class());
-			if(b){
+			StateBehaviour* b = (StateBehaviour*)agl_actor__find_behaviour (actor, state_get_class());
+			if (b) {
 				ParamArray* params = b->params;
-				if(params){
-					for(int i = 0; i < params->size; i++){
+				if (params) {
+					for (int i = 0; i < params->size; i++) {
 						ConfigParam* param = &params->params[i];
-						switch(param->utype){
+						switch (param->utype) {
 							case G_TYPE_STRING:
 								if(!yaml_add_key_value_pair(param->name, param->val.c)) goto error;
 								break;
@@ -575,28 +651,28 @@ save_settings ()
 				}
 			}
 
-			if(!b || b->is_container){
-				for(GList* l = actor->children;l;l=l->next){
-					if(!add_child(event, l->data)) goto error;
+			if (!b || b->is_container) {
+				for (GList* l = actor->children;l;l=l->next) {
+					if (!add_child(event, l->data)) goto error;
 				}
 			}
 
-			end_map_(event);
+			end_map(event);
 		}
 		return true;
 	  error:
 		return false;
 	}
 
-	map_open_(&event, "windows");
-	map_open_(&event, "window");
-	if(!((AGlActor*)app->scene)->children || !add_child(&event, (AGlActor*)app->scene)) goto close;
-	end_map_(&event);
-	end_map_(&event);
+	map_open(&event, "windows");
+	map_open(&event, "window");
+	if (!((AGlActor*)app->scene)->children || !add_child(&event, (AGlActor*)app->scene)) goto close;
+	end_map(&event);
+	end_map(&event);
 
-	EMIT(yaml_mapping_end_event_initialize(&event));
+	EMIT_(yaml_mapping_end_event_initialize(&event));
 
-	end_document;
+	end_document(&emitter);
 	yaml_event_delete(&event);
 	yaml_emitter_delete(&emitter);
 	fclose(fp);
@@ -604,7 +680,7 @@ save_settings ()
 
 	char* filename = g_strdup_printf("%s.yaml", app->config_ctx.filename);
 	if(g_rename (tmp, filename)){
-		gwarn("failed to save config");
+		pwarn("failed to save config");
 	}
 	g_free(filename);
 	g_free(tmp);
@@ -635,4 +711,3 @@ save_settings ()
 	return false;
 }
 
-
