@@ -1,7 +1,7 @@
 /**
 * +----------------------------------------------------------------------+
 * | This file is part of Samplecat. http://ayyi.github.io/samplecat/     |
-* | copyright (C) 2019-2019 Tim Orford <tim@orford.org>                  |
+* | copyright (C) 2019-2020 Tim Orford <tim@orford.org>                  |
 * +----------------------------------------------------------------------+
 * | This program is free software; you can redistribute it and/or modify |
 * | it under the terms of the GNU General Public License version 3       |
@@ -12,8 +12,8 @@
 #ifndef __views_context_menu_h__
 #define __views_context_menu_h__
 #include "agl/actor.h"
+#include "agl/x11.h"
 #include "wf/promise.h"
-#include "../glx.h"
 
 typedef struct {
     int code;
