@@ -1,14 +1,15 @@
-/**
-* +----------------------------------------------------------------------+
-* | This file is part of Samplecat. http://ayyi.github.io/samplecat/     |
-* | copyright (C) 2017-2019 Tim Orford <tim@orford.org>                  |
-* +----------------------------------------------------------------------+
-* | This program is free software; you can redistribute it and/or modify |
-* | it under the terms of the GNU General Public License version 3       |
-* | as published by the Free Software Foundation.                        |
-* +----------------------------------------------------------------------+
-*
-*/
+/*
+ +----------------------------------------------------------------------+
+ | This file is part of Samplecat. http://ayyi.github.io/samplecat/     |
+ | copyright (C) 2017-2025 Tim Orford <tim@orford.org>                  |
+ +----------------------------------------------------------------------+
+ | This program is free software; you can redistribute it and/or modify |
+ | it under the terms of the GNU General Public License version 3       |
+ | as published by the Free Software Foundation.                        |
+ +----------------------------------------------------------------------+
+ |
+ */
+
 #include "config.h"
 #include <glib.h>
 #include <glib-object.h>
@@ -35,8 +36,6 @@ struct _DirectoryViewClass {
 struct _DirectoryViewPrivate {
     gboolean    needs_update;
     int         cursor_base;      // Cursor when minibuffer opened
-    FmSortType  sort_type;
-    GtkSortType sort_order;
     int         (*sort_fn)(const void*, const void*);
 };
 
@@ -66,7 +65,7 @@ is_selected (DirectoryView* dv, int i)
 
 
 static gboolean
-_is_selected(DirectoryView* view, int i)
+_is_selected (DirectoryView* view, int i)
 {
 	return i == view->selection;
 }
@@ -244,31 +243,31 @@ free_view_item (ViewItem *view_item)
 
 
 static gint
-wrap_sort(gconstpointer a, gconstpointer b, DirectoryView* view)
+wrap_sort (gconstpointer a, gconstpointer b, DirectoryView* view)
 {
 	DirectoryViewPrivate* v = view->priv;
 
 	ViewItem* ia = *(ViewItem **) a;
 	ViewItem* ib = *(ViewItem **) b;
 
-	return v->sort_order == GTK_SORT_ASCENDING
+	return view->sort_order == GTK_SORT_ASCENDING
 		? v->sort_fn(ia->item, ib->item)
 		: -v->sort_fn(ia->item, ib->item);
 }
 
 
 static void
-resort(DirectoryView* view)
+resort (DirectoryView* view)
 {
 	DirectoryViewPrivate* v = view->priv;
 	ViewItem** items = (ViewItem**)view->items->pdata;
-	gint len = view->items->len;
+	guint len = view->items->len;
 
 	if (!len) return;
 
-	gint i;	for (i = len - 1; i >= 0; i--) items[i]->old_pos = i;
+	for (int i = len - 1; i >= 0; i--) items[i]->old_pos = i;
 
-	switch (v->sort_type) {
+	switch (view->sort_type) {
 		case SORT_NAME: v->sort_fn = sort_by_name; break;
 		case SORT_TYPE: v->sort_fn = sort_by_type; break;
 		case SORT_DATE: v->sort_fn = sort_by_date; break;
@@ -281,8 +280,8 @@ resort(DirectoryView* view)
 
 	g_ptr_array_sort_with_data(view->items, (GCompareDataFunc)wrap_sort, view);
 
-	guint* new_order = g_new(guint, len);
-	for (i = len - 1; i >= 0; i--) {
+	guint* new_order = g_malloc(len * sizeof(guint));
+	for (int i = len - 1; i >= 0; i--) {
 		new_order[i] = items[i]->old_pos;
 	}
 
@@ -298,18 +297,18 @@ resort(DirectoryView* view)
 static void
 directory_view_sort (ViewIface* view)
 {
-	//resort((DirectoryView *)view);
+	resort((DirectoryView*)view);
 }
 
 
 static void
-directory_view_style_changed(ViewIface *view, int flags)
+directory_view_style_changed (ViewIface *view, int flags)
 {
 	DirectoryView* dv = (DirectoryView*)view;
 	ViewItem** items = (ViewItem**)dv->items->pdata;
 	int n = dv->items->len;
 
-	int i; for (i = 0; i < n; i++) {
+	for (int i = 0; i < n; i++) {
 		ViewItem* item = items[i];
 		_g_object_unref0(item->image);
 	}
@@ -335,16 +334,16 @@ directory_view_add_items (ViewIface* _view, GPtrArray* new_items)
 	GPtrArray* items = view->items;
 	GtkTreeModel* model = (GtkTreeModel*)view->model;
 
-	//find the last row in the tree model
+	// Find the last row in the tree model
 	GtkTreeIter iter = {.user_data = GINT_TO_POINTER(items->len)};
 
 	GtkTreePath* path = details_get_path(model, &iter);
 
-	int i; for (i = 0; i < new_items->len; i++) {
+	for (int i = 0; i < new_items->len; i++) {
 		DirItem* item = (DirItem*)new_items->pdata[i];
 		char* leafname = item->leafname;
 
-		if(!vm_directory_match_filter(view->model, item)) continue;
+		if (!vm_directory_match_filter(view->model, item)) continue;
 		if (leafname[0] == '.') {
 			if (leafname[1] == '\0')
 				continue; // never show '.'
@@ -359,7 +358,7 @@ directory_view_add_items (ViewIface* _view, GPtrArray* new_items)
 				? NULL
 				: to_utf8(leafname)
 		);
-		dbg(2, "leaf=%20s owner=%3i size=%i", leafname, item->uid, item->size);
+		dbg(2, "leaf=%20s owner=%3i size=%lu", leafname, item->uid, item->size);
 
 		g_ptr_array_add(items, vitem); // !!! model just points to the garray entry???? !!!
 
@@ -380,7 +379,7 @@ directory_view_update_items (ViewIface* view, GPtrArray* items)
 	/* Find an item in the sorted array.
 	 * Returns the item number, or -1 if not found.
 	 */
-	int view_find_item(DirectoryView* view, DirItem *item)
+	int view_find_item (DirectoryView* view, DirItem *item)
 	{
 		g_return_val_if_fail(view, -1);
 		g_return_val_if_fail(item, -1);
@@ -420,9 +419,7 @@ directory_view_update_items (ViewIface* view, GPtrArray* items)
 	 */
 	resort(dv);
 
-	int i;
-	for (i = 0; i < items->len; i++)
-	{
+	for (int i = 0; i < items->len; i++) {
 		DirItem* item = (DirItem *) items->pdata[i];
 		const gchar* leafname = item->leafname;
 
@@ -516,27 +513,27 @@ directory_view_count_items (ViewIface* view)
 
 
 static int
-directory_view_count_selected(ViewIface* view)
+directory_view_count_selected (ViewIface* view)
 {
 	return 1;
 }
 
 
 static void
-directory_view_show_cursor(ViewIface* view)
+directory_view_show_cursor (ViewIface* view)
 {
 }
 
 
 static void
-directory_view_get_iter(ViewIface* view, ViewIter* iter, IterFlags flags)
+directory_view_get_iter (ViewIface* view, ViewIter* iter, IterFlags flags)
 {
 	make_iter((DirectoryView*)view, iter, flags);
 }
 
 
 static void
-directory_view_get_iter_at_point(ViewIface* view, ViewIter* iter, GdkWindow* src, int x, int y)
+directory_view_get_iter_at_point (ViewIface* view, ViewIter* iter, GdkWindow* src, int x, int y)
 {
 	DirectoryView* dv = (DirectoryView*)view;
 
@@ -547,7 +544,7 @@ directory_view_get_iter_at_point(ViewIface* view, ViewIter* iter, GdkWindow* src
 
 
 static void
-directory_view_cursor_to_iter(ViewIface *view, ViewIter *iter)
+directory_view_cursor_to_iter (ViewIface *view, ViewIter *iter)
 {
 #if 0
 	DirectoryView *dv = (DirectoryView *) view;
@@ -576,9 +573,9 @@ directory_view_cursor_to_iter(ViewIface *view, ViewIter *iter)
 static void
 directory_view_set_selected (ViewIface* view, ViewIter* iter, gboolean selected)
 {
-	void set_selected(DirectoryView* dv, int i, gboolean selected)
+	void set_selected (DirectoryView* dv, int i, gboolean selected)
 	{
-		if (selected){
+		if (selected) {
 			dv->selection = i;
 		}
 
@@ -612,14 +609,14 @@ directory_view_set_frozen (ViewIface* view, gboolean frozen)
 
 
 static gboolean
-directory_view_cursor_visible(ViewIface* view)
+directory_view_cursor_visible (ViewIface* view)
 {
 	return TRUE;
 }
 
 
 static void
-directory_view_set_base(ViewIface* view, ViewIter* iter)
+directory_view_set_base (ViewIface* view, ViewIter* iter)
 {
 	DirectoryView *dv = (DirectoryView *) view;
 
@@ -628,7 +625,7 @@ directory_view_set_base(ViewIface* view, ViewIter* iter)
 
 
 static void
-directory_view_start_lasso_box(ViewIface *view, GdkEventButton *event)
+directory_view_start_lasso_box (ViewIface *view, GdkEventButton *event)
 {
 #if 0
 	DirectoryView *dv = (DirectoryView *) view;
@@ -648,7 +645,7 @@ directory_view_start_lasso_box(ViewIface *view, GdkEventButton *event)
 
 
 static void
-directory_view_extend_tip(ViewIface *view, ViewIter *iter, GString *tip)
+directory_view_extend_tip (ViewIface *view, ViewIter *iter, GString *tip)
 {
 }
 
@@ -715,7 +712,7 @@ directory_view_new (VMDirectory* model, FilesView* view)
 	DirectoryView* dv = directory_view_construct (TYPE_DIRECTORY_VIEW);
 	dv->model = model;
 	dv->view = view;
-	dv->priv->sort_type = SORT_NAME;
+	dv->sort_type = SORT_NAME;
 	return dv;
 }
 
@@ -774,3 +771,17 @@ directory_view_finalize (GObject* obj)
 {
 	G_OBJECT_CLASS (directory_view_parent_class)->finalize (obj);
 }
+
+
+void
+directory_view_set_sort (DirectoryView* view, FmSortType sort, GtkSortType order)
+{
+	if (view->sort_type == sort && view->sort_order == order){
+		return;
+	}
+
+	view->sort_type = sort;
+	view->sort_order = order;
+
+	resort(view);
+}
