@@ -41,11 +41,12 @@ enum  {
 static GObject* ayyi_filemanager_constructor (GType, guint n_construct_properties, GObjectConstructParam*);
 static void     ayyi_filemanager_finalize    (GObject*);
 
-static void     detach                          (AyyiFilemanager*);
-static void     tidy_sympath                    (gchar*);
-static void     fm_next_thumb                   (GObject*, const gchar* path);
-static void     start_thumb_scanning            (AyyiFilemanager*);
-static void     fm_add_signals                  (AyyiFilemanager*);
+static void     update_display               (Directory*, DirAction, GPtrArray*, AyyiFilemanager*);
+static void     detach                       (AyyiFilemanager*);
+static void     tidy_sympath                 (gchar*);
+static void     fm_next_thumb                (GObject*, const gchar* path);
+static void     start_thumb_scanning         (AyyiFilemanager*);
+static void     fm_add_signals               (AyyiFilemanager*);
 
 static GdkCursor* crosshair = NULL; // TODO is never set
 
@@ -134,7 +135,7 @@ GType
 ayyi_filemanager_get_type (void)
 {
 	static volatile gsize ayyi_filemanager_type_id__volatile = 0;
-	if (g_once_init_enter (&ayyi_filemanager_type_id__volatile)) {
+	if (g_once_init_enter ((gsize*)&ayyi_filemanager_type_id__volatile)) {
 		static const GTypeInfo g_define_type_info = { sizeof (AyyiFilemanagerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) ayyi_filemanager_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AyyiFilemanager), 0, (GInstanceInitFunc) ayyi_filemanager_instance_init, NULL };
 		GType ayyi_filemanager_type_id;
 		ayyi_filemanager_type_id = g_type_register_static (G_TYPE_OBJECT, "AyyiFilemanager", &g_define_type_info, 0);
@@ -180,7 +181,8 @@ fm__change_to (AyyiFilemanager* fm, const char* path, const char* from)
 
 	char* from_dup = from && *from ? g_strdup(from) : NULL;
 
-	if(fm->directory) detach(fm);
+	if (fm->directory) detach(fm);
+
 	g_free(fm->real_path);
 	g_free(fm->sym_path);
 	fm->real_path = real_path;
@@ -604,8 +606,7 @@ detach (AyyiFilemanager* fm)
 	g_return_if_fail(fm->directory);
 
 	dir_detach(fm->directory, (DirCallback)update_display, fm);
-	g_object_unref(fm->directory);
-	fm->directory = NULL;
+	g_clear_pointer(&fm->directory, g_object_unref);
 }
 
 
@@ -781,8 +782,7 @@ set_scanning_display(AyyiFilemanager* fm, gboolean scanning)
 }
 
 
-//static
-void
+static void
 update_display (Directory* dir, DirAction action, GPtrArray* items, AyyiFilemanager* fm)
 {
 	ViewIface* view = (ViewIface*)fm->view;
