@@ -76,11 +76,16 @@ MIME_type* inode_door;
 
 
 void
-type_init(void)
+type_init (void)
 {
-	if(icon_theme) return;
+	if (icon_theme || type_hash) return;
 
-	icon_theme = gtk_icon_theme_get_default();
+	type_hash = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, NULL);
+
+	GdkScreen* screen = gdk_screen_get_default ();
+	if (!screen) return;
+
+	icon_theme = gtk_icon_theme_get_for_screen (screen);
 
 #ifdef DEBUG
 	gint n_elements;
@@ -92,8 +97,6 @@ type_init(void)
 	g_strfreev(*path);
 #endif
 
-	type_hash = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, NULL);
-
 	text_plain = get_mime_type("text/plain", TRUE);
 	inode_directory = get_mime_type("inode/directory", TRUE);
 	inode_mountpoint = get_mime_type("inode/mount-point", TRUE);
@@ -397,6 +400,7 @@ type_to_icon (MIME_type* type)
 
 	dbg(2, "theme=%s typename=%-20s gicon=%p info=%p", theme_name, type_name, icon, info);
 
+	g_object_unref(icon);
 	g_free(type_name);
 
 	if (info) {
