@@ -1,18 +1,18 @@
-/**
-* +----------------------------------------------------------------------+
-* | This file is part of the Ayyi project. http://ayyi.org               |
-* | copyright (C) 2011-2017 Tim Orford <tim@orford.org>                  |
-* +----------------------------------------------------------------------+
-* | This program is free software; you can redistribute it and/or modify |
-* | it under the terms of the GNU General Public License version 3       |
-* | as published by the Free Software Foundation.                        |
-* +----------------------------------------------------------------------+
-*
-*/
+/*
+ +----------------------------------------------------------------------+
+ | This file is part of the Ayyi project. https://www.ayyi.org          |
+ | copyright (C) 2011-2024 Tim Orford <tim@orford.org>                  |
+ +----------------------------------------------------------------------+
+ | This program is free software; you can redistribute it and/or modify |
+ | it under the terms of the GNU General Public License version 3       |
+ | as published by the Free Software Foundation.                        |
+ +----------------------------------------------------------------------+
+ |
+ */
+
 #include "config.h"
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <unistd.h>
 #include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -60,7 +60,7 @@ static void        MD5Transform    (guint32 buf[4], guint32 const in[16]);
  *  Like g_strdup, but does realpath() too (if possible)
  */
 char*
-pathdup(const char* path)
+pathdup (const char* path)
 {
 	char real[MAXPATHLEN];
 
@@ -235,7 +235,7 @@ format_size (off_t size)
  *  to a static buffer, valid until the next call.
  */
 const char*
-pretty_permissions(mode_t m)
+pretty_permissions (mode_t m)
 {
 	static char buffer[] = "rwx,rwx,rwx/UG"
 #ifdef S_ISVTX
@@ -288,18 +288,22 @@ pretty_time (const time_t *time)
 guchar*
 shell_escape (const guchar* word)
 {
-	GString* tmp = g_string_new(NULL);
+	GString* str = g_string_new(NULL);
 
 	while (*word) {
 		if (strchr(" ?*['\"$~\\|();!`&", *word))
-			g_string_append_c(tmp, '\\');
-		g_string_append_c(tmp, *word);
+			g_string_append_c(str, '\\');
+		g_string_append_c(str, *word);
 		word++;
 	}
 
-	guchar* retval = (guchar*)tmp->str;
-	g_string_free(tmp, FALSE);
+#ifdef HAVE_GLIB_2_76
+	return (guchar*)g_string_free_and_steal(str);
+#else
+	guchar* retval = (guchar*)str->str;
+	g_string_free(str, FALSE);
 	return retval;
+#endif
 }
 
 
@@ -309,7 +313,7 @@ shell_escape (const guchar* word)
  *  g_free() the result.
  */
 char*
-readlink_dup(const char* source)
+readlink_dup (const char* source)
 {
 	char path[MAXPATHLEN + 1];
 
@@ -358,7 +362,8 @@ struct _MD5Context {
 };
 
 #if G_BYTE_ORDER == G_BIG_ENDIAN
-static void byteSwap(guint32 *buf, unsigned words)
+static void
+byteSwap (guint32 *buf, unsigned words)
 {
 	md5byte *p = (md5byte *)buf;
 
@@ -378,7 +383,7 @@ static void byteSwap(guint32 *buf, unsigned words)
  * initialization constants.
  */
 static void
-MD5Init(MD5Context *ctx)
+MD5Init (MD5Context *ctx)
 {
 	ctx->buf[0] = 0x67452301;
 	ctx->buf[1] = 0xefcdab89;
@@ -395,7 +400,7 @@ MD5Init(MD5Context *ctx)
  * of bytes.
  */
 static void
-MD5Update(MD5Context *ctx, md5byte const *buf, unsigned len)
+MD5Update (MD5Context *ctx, md5byte const *buf, unsigned len)
 {
 	guint32 t;
 
@@ -436,7 +441,7 @@ MD5Update(MD5Context *ctx, md5byte const *buf, unsigned len)
  * Returns the newly allocated string of the hash.
  */
 static char*
-MD5Final(MD5Context *ctx)
+MD5Final (MD5Context *ctx)
 {
 	char *retval;
 	int i;
@@ -496,7 +501,7 @@ MD5Final(MD5Context *ctx)
  * the data and converts bytes into longwords for this routine.
  */
 static void
-MD5Transform(guint32 buf[4], guint32 const in[16])
+MD5Transform (guint32 buf[4], guint32 const in[16])
 {
 	register guint32 a, b, c, d;
 
@@ -704,7 +709,7 @@ collate_key_new (const guchar* name)
 }
 
 void
-collate_key_free(CollateKey *key)
+collate_key_free (CollateKey *key)
 {
 	CollatePart *part;
 
@@ -714,7 +719,7 @@ collate_key_free(CollateKey *key)
 }
 
 int
-collate_key_cmp(const CollateKey *key1, const CollateKey *key2, gboolean caps_first)
+collate_key_cmp (const CollateKey *key1, const CollateKey *key2, gboolean caps_first)
 {
 	g_return_val_if_fail(key1, 0);
 	g_return_val_if_fail(key2, 0);
@@ -901,7 +906,7 @@ file_extension(const char* path, char* extn)
  * FALSE if parent doesn't exist.
  */
 gboolean
-is_sub_dir(const char* sub_obj, const char* parent)
+is_sub_dir (const char* sub_obj, const char* parent)
 {
 	struct stat parent_info;
 
@@ -959,7 +964,7 @@ is_sub_dir(const char* sub_obj, const char* parent)
  * Returns an error string, or NULL on success. g_free() the result.
  */
 guchar*
-file_copy(const guchar* from, const guchar* to)
+file_copy (const guchar* from, const guchar* to)
 {
 	const char *argv[] = {"cp", "-pRf", NULL, NULL, NULL};
 
@@ -974,10 +979,11 @@ file_copy(const guchar* from, const guchar* to)
  * Check that path not moved into itself.
  */
 void
-file_move(const char* path, const char* dest)
+file_move (const char* path, const char* dest)
 {
-	if (is_sub_dir(make_dest_path(path, dest), path)) dbg(0, "!ERROR: Can't move/rename object into itself");
-	else {
+	if (is_sub_dir(make_dest_path(path, dest), path)) {
+		dbg(0, "!ERROR: Can't move/rename object into itself");
+	} else {
 		do_move(path, dest);
 		send_check_path(dest);
 	}
@@ -985,7 +991,7 @@ file_move(const char* path, const char* dest)
 
 
 static void
-do_move(const char *path, const char *dest)
+do_move (const char *path, const char *dest)
 {
 	const char* argv[] = {"mv", "-f", NULL, NULL, NULL};
 	struct stat	info2;
@@ -1047,22 +1053,22 @@ do_move(const char *path, const char *dest)
 	argv[3] = dest;
 
 	char* err = fork_exec_wait(argv);
-	if (err)
-	{
+	if (err) {
 		//printf_send("!%s\nFailed to move %s as %s\n", err, path, dest_path);
 		dbg(0, "!%s\nFailed to move %s as %s\n", err, path, dest);
 		dbg(0, "FIXME add print callback to application");
 		//statusbar_printf(1, "!%s: Failed to move %s as %s", err, path, dest);
 		g_free(err);
-	}
-	else
-	{
+
+	} else {
 		send_check_path(dest);
 
 		//if (is_dir) send_mount_path(path);
-		if (is_dir) dbg(0, "?%s", path);
-		//else        statusbar_printf(1, "file '%s' moved.", path);
-		else dbg(0, "FIXME add print callback to application");
+		if (is_dir)
+			dbg(0, "?%s", path);
+		else
+			//statusbar_printf(1, "file '%s' moved.", path);
+			dbg(0, "FIXME add print callback to application");
 	}
 }
 
@@ -1089,7 +1095,7 @@ pathdup(const char* path)
  * the same.
  */
 static const char*
-make_dest_path(const char *object, const char *dir)
+make_dest_path (const char *object, const char *dir)
 {
 	const char *leaf;
 
@@ -1110,7 +1116,7 @@ make_dest_path(const char *object, const char *dir)
 
 /* Notify the filer that this item has been updated */
 static void
-send_check_path(const gchar *path)
+send_check_path (const gchar *path)
 {
 	//printf_send("s%s", path);
 	dbg(0, "s%s", path);
@@ -1119,7 +1125,7 @@ send_check_path(const gchar *path)
 
 /* If the parent has sent any flag toggles, read them */
 static void
-check_flags(void)
+check_flags (void)
 {
 	fd_set set;
 	int	got;
@@ -1146,7 +1152,8 @@ check_flags(void)
 }
 
 
-static void process_flag(char flag)
+static void
+process_flag (char flag)
 {
 	dbg(0, "...");
 #if 0
@@ -1220,20 +1227,16 @@ fork_exec_wait (const char** argv)
 
 
 gchar*
-uri_text_from_list(GList *list, gint *len, gint plain_text)
+uri_text_from_list (GList *list, gint *len, gint plain_text)
 {
-    gchar *uri_text = NULL;
-    GString *string;
-    GList *work;
-
     if (!list) {
         if (len) *len = 0;
         return NULL;
     }
 
-    string = g_string_new("");
+    GString* string = g_string_new("");
 
-    work = list;
+    GList* work = list;
     while (work) {
         const gchar *name8; /* dnd filenames are in utf-8 */
 
@@ -1259,15 +1262,19 @@ uri_text_from_list(GList *list, gint *len, gint plain_text)
         work = work->next;
         }
 
-    uri_text = string->str;
     if (len) *len = string->len;
+#ifdef HAVE_GLIB_2_76
+    gchar* uri_text = g_string_free_and_steal(string);
+#else
+    gchar* uri_text = string->str;
     g_string_free(string, FALSE);
+#endif
 
     return uri_text;
 }
 
 static void
-uri_list_parse_encoded_chars(GList *list)
+uri_list_parse_encoded_chars (GList *list)
 {
     GList *work = list;
 
@@ -1282,7 +1289,7 @@ uri_list_parse_encoded_chars(GList *list)
 }
 
 GList*
-uri_list_from_text(gchar *data, gint files_only)
+uri_list_from_text (gchar *data, gint files_only)
 {
     GList *list = NULL;
     gint b, e;
@@ -1343,7 +1350,7 @@ static gint escape_char_list[] = {
 static gchar *hex_char = "0123456789ABCDEF";
 
 static gint
-escape_test(guchar c)
+escape_test (guchar c)
 {
     if (c < 32 || c > 127) return TRUE;
     return (escape_char_list[c] != 0);
@@ -1351,7 +1358,7 @@ escape_test(guchar c)
 
 
 static const gchar*
-escape_code(guchar c)
+escape_code (guchar c)
 {
     static gchar text[4];
 
@@ -1365,17 +1372,13 @@ escape_code(guchar c)
 
 
 gchar*
-uri_text_escape(const gchar *text)
+uri_text_escape (const gchar *text)
 {
-    GString *string;
-    gchar *result;
-    const gchar *p;
-
     if (!text) return NULL;
 
-    string = g_string_new("");
+    GString* string = g_string_new("");
 
-    p = text;
+    const gchar* p = text;
     while (*p != '\0')
         {
         if (escape_test(*p))
@@ -1389,8 +1392,12 @@ uri_text_escape(const gchar *text)
         p++;
         }
 
-    result = string->str;
-    g_string_free(string, FALSE);
+#ifdef HAVE_GLIB_2_76
+    gchar *result = g_string_free_and_steal(string);
+#else
+	gchar *result = string->str;
+	g_string_free(string, FALSE);
+#endif
 
     /* dropped filenames are expected to be utf-8 compatible */
     if (!g_utf8_validate(result, -1, NULL))
@@ -1409,7 +1416,8 @@ uri_text_escape(const gchar *text)
 }
 
 /* this operates on the passed string, decoding escaped characters */
-void uri_text_decode(gchar *text)
+void
+uri_text_decode (gchar *text)
 {
     if (strchr(text, '%'))
         {
@@ -1460,15 +1468,13 @@ void uri_text_decode(gchar *text)
  *  g_object_unref() the return value whether the function fails or not).
  */
 GdkPixbuf*
-create_spotlight_pixbuf(GdkPixbuf *src, GdkColor *color)
+create_spotlight_pixbuf (GdkPixbuf* src, GdkColor* color)
 {
     guchar opacity = 192;
     guchar alpha = 255 - opacity;
-    GdkPixbuf *dst;
     GdkColorspace colorspace;
-    int width, height, src_rowstride, dst_rowstride, x, y;
+    int src_rowstride, dst_rowstride, x, y;
     int n_channels, bps;
-    int r, g, b;
     guchar *spixels, *dpixels, *src_pixels, *dst_pixels;
     gboolean has_alpha;
 
@@ -1483,10 +1489,10 @@ create_spotlight_pixbuf(GdkPixbuf *src, GdkColor *color)
         (bps != 8))
         goto error;
 
-    width = gdk_pixbuf_get_width(src);
-    height = gdk_pixbuf_get_height(src);
+    int width = gdk_pixbuf_get_width(src);
+    int height = gdk_pixbuf_get_height(src);
 
-    dst = gdk_pixbuf_new(colorspace, has_alpha, bps, width, height);
+    GdkPixbuf* dst = gdk_pixbuf_new(colorspace, has_alpha, bps, width, height);
     if (dst == NULL)
         goto error;
 
@@ -1495,16 +1501,14 @@ create_spotlight_pixbuf(GdkPixbuf *src, GdkColor *color)
     src_rowstride = gdk_pixbuf_get_rowstride(src);
     dst_rowstride = gdk_pixbuf_get_rowstride(dst);
 
-    r = opacity * (color->red >> 8);
-    g = opacity * (color->green >> 8);
-    b = opacity * (color->blue >> 8);
+    int r = opacity * (color->red >> 8);
+    int g = opacity * (color->green >> 8);
+    int b = opacity * (color->blue >> 8);
 
-    for (y = 0; y < height; y++)
-    {
+    for (y = 0; y < height; y++) {
         spixels = src_pixels + y * src_rowstride;
         dpixels = dst_pixels + y * dst_rowstride;
-        for (x = 0; x < width; x++)
-        {
+        for (x = 0; x < width; x++) {
             *dpixels++ = (*spixels++ * alpha + r) >> 8;
             *dpixels++ = (*spixels++ * alpha + g) >> 8;
             *dpixels++ = (*spixels++ * alpha + b) >> 8;
@@ -1576,7 +1580,7 @@ path_to_utf8 (const gchar *path)
 }
 
 void
-fm__escape_for_menu(char* string)
+fm__escape_for_menu (char* string)
 {
 	//gtk uses underscores as nmemonic identifiers, so any literal underscores need to be escaped.
 
