@@ -179,8 +179,7 @@ static gchar*
 samplecat_value_idle_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags)
 {
 	if (collect_values[0].v_pointer) {
-		SamplecatIdle* object;
-		object = collect_values[0].v_pointer;
+		SamplecatIdle* object = collect_values[0].v_pointer;
 		if (object->parent_instance.g_class == NULL) {
 			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
 		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
@@ -197,8 +196,7 @@ samplecat_value_idle_collect_value (GValue* value, guint n_collect_values, GType
 static gchar*
 samplecat_value_idle_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags)
 {
-	SamplecatIdle** object_p;
-	object_p = collect_values[0].v_pointer;
+	SamplecatIdle** object_p = collect_values[0].v_pointer;
 	if (!object_p) {
 		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
 	}
@@ -315,7 +313,7 @@ static GType
 samplecat_idle_get_type (void)
 {
 	static volatile gsize samplecat_idle_type_id__volatile = 0;
-	if (g_once_init_enter (&samplecat_idle_type_id__volatile)) {
+	if (g_once_init_enter ((gsize*)&samplecat_idle_type_id__volatile)) {
 		static const GTypeValueTable g_define_type_value_table = { samplecat_value_idle_init, samplecat_value_idle_free_value, samplecat_value_idle_copy_value, samplecat_value_idle_peek_pointer, "p", samplecat_value_idle_collect_value, "p", samplecat_value_idle_lcopy_value };
 		static const GTypeInfo g_define_type_info = { sizeof (SamplecatIdleClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) samplecat_idle_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SamplecatIdle), 0, (GInstanceInitFunc) samplecat_idle_instance_init, &g_define_type_value_table };
 		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
@@ -442,6 +440,9 @@ samplecat_model_remove (SamplecatModel* self, gint id)
 }
 
 
+/*
+ *  Takes ownership of `dir`
+ */
 void
 samplecat_model_set_search_dir (SamplecatModel* self, gchar* dir)
 {
@@ -518,9 +519,8 @@ samplecat_model_refresh_sample (SamplecatModel* self, Sample* sample, gboolean f
 	time_t mtime = file_mtime (sample->full_path);
 	if (mtime > ((time_t) 0)) {
 		if (force_update || sample->mtime < mtime) {
-			Sample* test = sample_new_from_filename (sample->full_path, FALSE);
-			if (!(test)) {
-				_sample_unref0 (test);
+			g_autoptr(Sample) test = sample_new_from_filename (sample->full_path, FALSE);
+			if (!test) {
 				return;
 			}
 			if (sample_get_file_info (sample)) {
@@ -532,7 +532,6 @@ samplecat_model_refresh_sample (SamplecatModel* self, Sample* sample, gboolean f
 			} else {
 				dbg (0, "full update - reading file info failed!");
 			}
-			_sample_unref0 (test);
 		}
 		sample->mtime = mtime;
 		sample->online = TRUE;
@@ -593,26 +592,10 @@ samplecat_model_update_sample (SamplecatModel* self, Sample* sample, gint prop,
 		}
 		case COL_X_NOTES:
 		{
-			Sample* _tmp46_;
-			gint _tmp47_;
-			void* _tmp48_;
-			gboolean _tmp49_ = FALSE;
-			gboolean _tmp50_;
-			_tmp46_ = sample;
-			_tmp47_ = _tmp46_->id;
-			_tmp48_ = val;
-			_tmp49_ = backend.update_string (_tmp47_, "notes", (gchar*) _tmp48_);
-			ok = _tmp49_;
-			_tmp50_ = ok;
-			if (_tmp50_) {
-				Sample* _tmp51_;
-				void* _tmp52_;
-				gchar* _tmp53_;
-				_tmp51_ = sample;
-				_tmp52_ = val;
-				_tmp53_ = g_strdup ((const gchar*) _tmp52_);
-				_g_free0 (_tmp51_->notes);
-				_tmp51_->notes = _tmp53_;
+			if((ok = backend.update_string (sample->id, "notes", (gchar*)val))){
+				gchar* str = g_strdup ((const gchar*)val);
+				_g_free0 (sample->notes);
+				sample->notes = str;
 			}
 			break;
 		}
@@ -861,13 +844,17 @@ static void
 samplecat_model_finalize (GObject* obj)
 {
 	SamplecatModel* self = G_TYPE_CHECK_INSTANCE_CAST (obj, SAMPLECAT_TYPE_MODEL, SamplecatModel);
+
 	g_list_free0 (self->backends);
-	for(int i = 0; i < N_FILTERS; i++){
-		g_free(self->filters3[i]->value.c);
-		observable_free(self->filters3[i]);
+
+	for (int i = 0; i < N_FILTERS; i++) {
+		g_free (self->filters3[i]->value.c);
+		agl_observable_free (self->filters3[i]);
 	}
+
 	_samplecat_idle_unref0 (self->priv->dir_idle);
 	_samplecat_idle_unref0 (self->priv->sample_changed_idle);
 	g_list_free0 (self->modified);
+
 	G_OBJECT_CLASS (samplecat_model_parent_class)->finalize (obj);
 }
