@@ -1,7 +1,7 @@
 /**
 * +----------------------------------------------------------------------+
 * | This file is part of the Ayyi project. http://www.ayyi.org           |
-* | copyright (C) 2018-2020 Tim Orford <tim@orford.org>                  |
+* | copyright (C) 2018-2021 Tim Orford <tim@orford.org>                  |
 * +----------------------------------------------------------------------+
 * | This program is free software; you can redistribute it and/or modify |
 * | it under the terms of the GNU General Public License version 3       |
@@ -12,21 +12,9 @@
 #ifndef __observable_h__
 #define __observable_h__
 
-typedef union
-{
-    int         i;
-    float       f;
-    double      d;
-    char*       c;
+#include "agl/observable.h"
 
-} AMVal;
-
-typedef struct {
-   AMVal  value;
-   AMVal  min;
-   AMVal  max;
-   GList* subscriptions;
-} Observable;
+typedef AGlObservable Observable;
 
 typedef struct {
    Observable  observable;
@@ -44,22 +32,14 @@ typedef struct {
    PtChangeType change;
 } PtObservable;
 
-typedef void (*ObservableFn) (Observable*, AMVal, gpointer);
-
-Observable* observable_new         ();
 Observable* named_observable_new   (const char*);
-void        observable_free        (Observable*);
-void        observable_set         (Observable*, AMVal);
-void        observable_subscribe   (Observable*, ObservableFn, gpointer);
-void        observable_subscribe_with_state
-                                   (Observable*, ObservableFn, gpointer);
-void        observable_unsubscribe (Observable*, ObservableFn, gpointer);
+void        observable_set         (Observable*, AGlVal);
 
 Observable* observable_float_new   (float val, float min, float max);
-void        observable_float_set   (Observable*, float);
+void        observable_set_float   (Observable*, float);
 
 void        observable_string_set  (Observable*, const char*);
 
-#define     observable_free0(A)    (observable_free(A), A = NULL)
+#define     observable_free0(A)    (agl_observable_free(A), A = NULL)
 
 #endif
