@@ -1,50 +1,39 @@
 /*
-  Tests for opengl textures using large files
+ +----------------------------------------------------------------------+
+ | This file is part of the Ayyi project. https://www.ayyi.org          |
+ | copyright (C) 2013-2025 Tim Orford <tim@orford.org>                  |
+ +----------------------------------------------------------------------+
+ | This program is free software; you can redistribute it and/or modify |
+ | it under the terms of the GNU General Public License version 3       |
+ | as published by the Free Software Foundation.                        |
+ +----------------------------------------------------------------------+
+ |
+ | Tests for opengl textures using large files
+ |
+ | Automated, opens a gui window.
+ |
+ |  1-test basic hires
+ |  2-test textures are loaded when scrolling
+ |      Shows many different views at using all modes to check that the cache
+ |      works when full and that the correct data for the view is available.
+ |  3-test texture cache is emptied at lowres when the Waveform is free'd.
+ |
+ */
 
-  Automated, opens a gui window.
-
-  1-test basic hires
-  2-test textures are loaded when scrolling
-      Shows many different views at using all modes to check that the cache
-      works when full and that the correct data for the view is available.
-  3-test texture cache is emptied at lowres when the Waveform is free'd.
-
-  ---------------------------------------------------------------
-
-  copyright (C) 2013-2020 Tim Orford <tim@orford.org>
-
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License version 3
-  as published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-
-*/
 #define __wf_private__
+
 #include "config.h"
-#include <getopt.h>
-#include <time.h>
-#include <sys/time.h>
-#include <math.h>
 #pragma GCC diagnostic ignored "-Wdeprecated-declarations"
 #include <gtk/gtk.h>
 #pragma GCC diagnostic warning "-Wdeprecated-declarations"
-#include <gdk/gdkkeysyms.h>
-#include <glib/gstdio.h>
-#include "agl/utils.h"
+#include "agl/gtk.h"
 #include "wf/audio.h"
 #include "wf/worker.h"
 #include "waveform/actor.h"
 #include "waveform/texture_cache.h"
 #include "waveform/ui-private.h"
 #include "test/common.h"
+#include "test/utils.h"
 
 extern void texture_cache_print ();
 extern void hi_ng_cache_print   ();
@@ -54,6 +43,16 @@ extern void hi_ng_cache_print   ();
 #define WAV1 "large1.wav"
 #define WAV2 "large2.wav"
 
+WfTest* wf_test_new();
+
+#define NEW_TEST() \
+	({ \
+	g_strlcpy(TEST.current.name, __func__, 64); \
+	printf("%srunning %i of %zu: %s%s ...\n", ayyi_bold, TEST.current.test + 1, G_N_ELEMENTS(tests), __func__, ayyi_white); \
+	if(TEST.current.finished) return; \
+	wf_test_new(); \
+	})
+
 GdkGLConfig*    glconfig       = NULL;
 static bool     gl_initialised = false;
 GtkWidget*      canvas         = NULL;
@@ -81,29 +80,29 @@ gpointer tests[] = {
 };
 
 
-int
-main (int argc, char *argv[])
+bool
+setup (int argc, char* argv[])
 {
-	wf_debug = 0;
-	test_init(tests, G_N_ELEMENTS(tests));
- 
+	TEST.is_gtk = true;
+	TEST.n_tests = G_N_ELEMENTS(tests);
+
 	ready = am_promise_new(NULL);
 
 	gtk_init(&argc, &argv);
-	if(!(glconfig = gdk_gl_config_new_by_mode(GDK_GL_MODE_RGBA | GDK_GL_MODE_DEPTH | GDK_GL_MODE_DOUBLE))){
-		perr ("Cannot initialise gtkglext."); return EXIT_FAILURE;
+	if (!(glconfig = gdk_gl_config_new_by_mode(GDK_GL_MODE_RGBA | GDK_GL_MODE_DEPTH | GDK_GL_MODE_DOUBLE))) {
+		perr ("Cannot initialise gtkglext.");
+		return EXIT_FAILURE;
 	}
 
 	GtkWidget* window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 
 	canvas = gtk_drawing_area_new();
-#ifdef HAVE_GTK_2_18
 	gtk_widget_set_can_focus     (canvas, true);
-#endif
 	gtk_widget_set_size_request  (canvas, GL_WIDTH, 128);
 	gtk_widget_set_gl_capability (canvas, glconfig, NULL, 1, GDK_GL_RGBA_TYPE);
 	gtk_widget_add_events        (canvas, GDK_POINTER_MOTION_MASK | GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK);
 	gtk_container_add            ((GtkContainer*)window, (GtkWidget*)canvas);
+
 	g_signal_connect((gpointer)canvas, "realize",       G_CALLBACK(on_canvas_realise), NULL);
 	g_signal_connect((gpointer)canvas, "size-allocate", G_CALLBACK(on_allocate), NULL);
 
@@ -113,7 +112,7 @@ main (int argc, char *argv[])
 
 	gtk_main();
 
-	return EXIT_SUCCESS;
+	return 0;
 }
 
 
@@ -121,15 +120,15 @@ void
 create_files ()
 {
 	START_TEST;
-	reset_timeout(60000);
+	test_reset_timeout(60000);
 
 	char* wavs[] = {WAV1, WAV2};
 
-	int i; for(i=0;i<G_N_ELEMENTS(wavs);i++){
+	for (int i=0;i<G_N_ELEMENTS(wavs);i++) {
 		char* filename = find_wav(wavs[i]);
-		if(filename){
+		if (filename) {
 			wf_free(filename);
-		}else{
+		} else {
 			const char* dir = find_data_dir();
 			assert(dir, "data dir not found");
 
@@ -150,8 +149,7 @@ __test_shown (gpointer _c)
 	WfTest* c = _c;
 #ifdef AGL_ACTOR_RENDER_CACHE
 	AGlActor* actor = (AGlActor*)a[0];
-	if(actor->cache.valid){
-	}else{
+	if (!actor->cache.valid) {
 		extern bool wf_actor_test_is_not_blank(WaveformActor*);
 		assert_and_stop(wf_actor_test_is_not_blank(a[0]), "output is blank");
 	}
@@ -195,9 +193,9 @@ test_hires ()
 
 	assert(wfc, "canvas not created");
 
-	void set_region()
+	void set_region ()
 	{
-		int i; for(i=0;i<G_N_ELEMENTS(a)&&a[i];i++)
+		for (int i=0;i<G_N_ELEMENTS(a)&&a[i];i++)
 			wf_actor_set_region(a[i], &(WfSampleRegion){
 				0,
 				REGION_LEN
@@ -251,7 +249,7 @@ test_hires ()
 				#define ZOOM_V_LO (1.0/65536) // px_per_sample - transition point from v-low-res to low-res.
 
 				static inline int
-				get_resolution(double zoom)
+				get_resolution (double zoom)
 				{
 					return (zoom > ZOOM_HI)
 						? 1
@@ -265,7 +263,7 @@ test_hires ()
 				}
 
 				static inline Mode
-				get_mode(double zoom)
+				get_mode (double zoom)
 				{
 					return (zoom > ZOOM_HI)
 						? MODE_V_HI
@@ -296,14 +294,14 @@ test_hires ()
 
 #ifdef LATER
 				static double
-				wf_actor_samples2gl(double zoom, uint32_t n_samples)
+				wf_actor_samples2gl (double zoom, uint32_t n_samples)
 				{
 					//zoom is pixels per sample
 					return n_samples * zoom;
 				}
 
 				static BlockRange
-				wf_actor_get_visible_block_range(WfSampleRegion* region, WfRectangle* rect, double zoom, WfViewPort* viewport_px, int textures_size)
+				wf_actor_get_visible_block_range (WfSampleRegion* region, WfRectangle* rect, double zoom, WfViewPort* viewport_px, int textures_size)
 				{
 					//the region, rect and viewport are passed explictly because different users require slightly different values during transitions.
 
@@ -329,20 +327,20 @@ test_hires ()
 					}
 
 					// find first block
-					if(rect->left <= viewport_px->right){
+					if (rect->left <= viewport_px->right) {
 
-						int b; for(b=region_start_block;b<=region_end_block-1;b++){ // stop before the last block
+						for (int b=region_start_block;b<=region_end_block-1;b++) { // stop before the last block
 							int block_start_px = file_start_px + b * block_wid;
 							double block_end_px = block_start_px + block_wid;
 							dbg(3, "block_pos_px=%i", block_start_px);
-							if(block_end_px >= viewport_px->left){
+							if (block_end_px >= viewport_px->left) {
 								range.first = b;
 								goto next;
 							}
 						}
 						// check last block:
 						double block_end_px = file_start_px + wf_actor_samples2gl(zoom, region->start + region->len);
-						if(block_end_px >= viewport_px->left){
+						if (block_end_px >= viewport_px->left) {
 							range.first = b;
 							goto next;
 						}
@@ -354,17 +352,17 @@ test_hires ()
 					next:
 
 					// find last block
-					if(rect->left <= viewport_px->right){
+					if (rect->left <= viewport_px->right) {
 						int last = range.last = MIN(range.first + WF_MAX_BLOCK_RANGE, region_end_block);
 
 						g_return_val_if_fail(viewport_px->right - viewport_px->left > 0.01, range);
 
 						//crop to viewport:
-						int b; for(b=region_start_block;b<=last-1;b++){ //note we dont check the last block which can be partially outside the viewport
+						for (int b=region_start_block;b<=last-1;b++) { //note we dont check the last block which can be partially outside the viewport
 							float block_end_px = file_start_px + (b + 1) * block_wid;
 							//dbg(1, " %i: block_px: %.1f --> %.1f", b, block_end_px - (int)block_wid, block_end_px);
-							if(block_end_px > viewport_px->right) dbg(2, "end %i clipped by viewport at block %i. vp.right=%.2f block_end=%.1f", region_end_block, MAX(0, b/* - 1*/), viewport_px->right, block_end_px);
-							if(block_end_px > viewport_px->right){
+							if (block_end_px > viewport_px->right) dbg(2, "end %i clipped by viewport at block %i. vp.right=%.2f block_end=%.1f", region_end_block, MAX(0, b/* - 1*/), viewport_px->right, block_end_px);
+							if (block_end_px > viewport_px->right) {
 								range.last = MAX(0, b/* - 1*/);
 								goto out;
 							}
@@ -402,9 +400,9 @@ get_random_region (WaveformActor* a, Mode mode, uint32_t max_scroll)
 		MIN(a->region.start + max_scroll, a->waveform->n_frames - len_range + 1)
 						)
 	);
-																	//dbg(0, "start range: %i %i (max_scroll=%u)", min_start, MIN(a->region.start + max_scroll, a->waveform->n_frames - len_range + 1), max_scroll);
+
 	int len = min + g_random_int_range(0, len_range + 1);
-	dbg(1, "r=%Lu", start);
+	dbg(1, "r=%"PRIi64, start);
 
 	if(start + len > a->waveform->n_frames){
 		// the above calculation failed
@@ -415,12 +413,12 @@ get_random_region (WaveformActor* a, Mode mode, uint32_t max_scroll)
 }
 
 
-typedef struct {
+typedef struct C {
 	int test_idx;
 	int n;
 	int iter;
 	int wait_count;
-	void (*next)();
+	void (*next)(struct C*);
 	uint64_t start;
 } C;
 
@@ -435,7 +433,7 @@ _check_scroll (gpointer _c)
 	assert_and_stop(animatable->val.i == *animatable->model_val.i, "animation not finished");
 	*/
 
-	if(g_list_length(((AGlActor*)a[0])->transitions)) return TIMER_CONTINUE; // not yet ready
+	if (g_list_length(((AGlActor*)a[0])->transitions)) return G_SOURCE_CONTINUE; // not yet ready
 
 	c->wait_count++;
 
@@ -454,21 +452,21 @@ _check_scroll (gpointer _c)
 	WfBuf16* buf = audio->buf16[region_start_block];
 	WfWorker* worker = &wf->audio_worker;
 	int n_jobs = g_list_length(worker->jobs);
-	if(n_jobs || !buf){
-		if(c->wait_count < 30) return TIMER_CONTINUE;
+	if (n_jobs || !buf) {
+		if (c->wait_count < 30) return G_SOURCE_CONTINUE;
 	}
 
 	//assert_and_stop(c->wait_count < 30, "timeout loading blocks");
 	assert_and_stop(buf, "buf is empty %i", region_start_block);
 	assert_and_stop(!n_jobs, "jobs still pending: %i", n_jobs);
 
-	if(++c->iter < c->n){
+	if (++c->iter < c->n) {
 		c->next(c);
-	}else{
+	} else {
 		WF_TEST_FINISH_TIMER_STOP;
 	}
 
-	return TIMER_STOP;
+	return G_SOURCE_REMOVE;
 }
 
 
@@ -481,7 +479,7 @@ next_scroll (C* c)
 	WfSampleRegion region = get_random_region(a[0], MODE_V_HI, UINT_MAX);
 	c->start = region.start;
 
-	int i; for(i=0;i<G_N_ELEMENTS(a)&&a[i];i++)
+	for (int i=0;i<G_N_ELEMENTS(a)&&a[i];i++)
 		wf_actor_set_region(a[i], &region);
 
 	g_timeout_add(200, _check_scroll, c);
@@ -495,7 +493,7 @@ test_scroll ()
 
 	C* c = WF_NEW(C,
 		.test_idx = __test_idx,
-		.n = 256,
+		.n = 128,
 		.next = next_scroll,
 	);
 
@@ -524,13 +522,13 @@ test_scroll ()
 }
 
 
-typedef struct {
+typedef struct C3 {
 	int            test_idx;
 	int            n;
 	int            iter;
 	int            wait_count;
 	WfSampleRegion region[2];
-	void (*next)();
+	void (*next)(struct C3*);
 } C3;
 
 		gboolean _hi_check_scroll(gpointer data)
@@ -542,7 +540,7 @@ typedef struct {
 			assert_and_stop(animatable->val.i == *animatable->model_val.i, "animation not finished");
 			*/
 
-			if(g_list_length(((AGlActor*)a[0])->transitions)) return TIMER_CONTINUE; // not yet ready
+			if (g_list_length(((AGlActor*)a[0])->transitions)) return G_SOURCE_CONTINUE; // not yet ready
 
 			c->wait_count++;
 
@@ -561,7 +559,7 @@ typedef struct {
 			WfBuf16* buf = audio->buf16[region_start_block];
 			int n_jobs = g_list_length(wf->audio_worker.jobs);
 			if(n_jobs || !buf){
-				if(c->wait_count < 30) return TIMER_CONTINUE;
+				if(c->wait_count < 30) return G_SOURCE_CONTINUE;
 			}
 
 			//assert_and_stop(wait_count < 30, "timeout loading blocks");
@@ -581,7 +579,12 @@ typedef struct {
 			return G_SOURCE_REMOVE;
 		}
 
-	void hi_next_scroll(C3* c)
+void
+test_hi_double ()
+{
+	START_LONG_TEST;
+
+	void hi_next_scroll (C3* c)
 	{
 		static int timeouts[] =  {1000,   700,   600,    500,    400,      300,     100};
 		static uint64_t move[] = {4096, 16384, 65536, 262144, 1048576, 4194304, INT_MAX};
@@ -590,7 +593,7 @@ typedef struct {
 		int stage = MIN(G_N_ELEMENTS(move) - 1, c->iter / 8);
 		dbg(0, "------------------------- %i %i", c->iter, stage);
 
-		int i; for(i=0;i<G_N_ELEMENTS(a);i++){
+		for (int i=0;i<G_N_ELEMENTS(a);i++) {
 			c->region[i] = get_random_region(a[i], MODE_HI, move[stage]);
 			wf_actor_set_region(a[i], &c->region[i]);
 		}
@@ -598,12 +601,7 @@ typedef struct {
 		g_timeout_add(timeouts[stage], _hi_check_scroll, c);
 	}
 
-void
-test_hi_double()
-{
-	START_LONG_TEST;
-
-	void add_actor(int i)
+	void add_actor (int i)
 	{
 		{
 			char* filename = find_wav(WAV2);
@@ -613,7 +611,7 @@ test_hi_double()
 			wf_free(filename);
 		}
 
-		a[i] = wf_canvas_add_new_actor(wfc, w[i]);
+		a[i] = wf_context_add_new_actor(wfc, w[i]);
 		assert(a[i], "failed to create actor");
 
 		agl_actor__add_child((AGlActor*)scene, (AGlActor*)a[i]);
@@ -625,7 +623,7 @@ test_hi_double()
 
 	hi_next_scroll(WF_NEW(C3,
 		.test_idx = __test_idx,
-		.n = 256,
+		.n = 128,
 		.next = hi_next_scroll,
 	));
 }
@@ -697,7 +695,7 @@ test_hi_double()
 			}
 
 			g_timeout_add(2000, check_not_in_cache, c);
-			return TIMER_STOP;
+			return G_SOURCE_REMOVE;
 		}
 
 static void
@@ -797,15 +795,15 @@ gl_init ()
 static gboolean
 __on_canvas_realise (gpointer user_data)
 {
-	if(!files_created){
+	if (!files_created) {
 		return G_SOURCE_CONTINUE;
 	}
 
 	gl_init();
 
-	wfc = wf_context_new((AGlActor*)(scene = (AGlScene*)agl_actor__new_root(canvas)));
+	wfc = wf_context_new((AGlActor*)(scene = (AGlScene*)agl_new_scene_gtk(canvas)));
 
-	g_signal_connect((gpointer)canvas, "expose-event",  G_CALLBACK(agl_actor__on_expose), scene);
+	g_signal_connect((gpointer)canvas, "expose-event", G_CALLBACK(agl_actor__on_expose), scene);
 
 	{
 		char* filename = find_wav(WAV1);
@@ -824,7 +822,7 @@ __on_canvas_realise (gpointer user_data)
 	};
 
 	int i; for(i=0;i<1;i++){ // initially only create 1 actor
-		agl_actor__add_child((AGlActor*)scene, (AGlActor*)(a[i] = wf_canvas_add_new_actor(wfc, w[0])));
+		agl_actor__add_child((AGlActor*)scene, (AGlActor*)(a[i] = wf_context_add_new_actor(wfc, w[0])));
 
 		wf_actor_set_region(a[i], &region[i]);
 		wf_actor_set_colour(a[i], colours[i][0]);
@@ -859,9 +857,6 @@ on_allocate (GtkWidget* widget, GtkAllocation* allocation, gpointer user_data)
 	((AGlActor*)scene)->region.x2 = allocation->width;
 	((AGlActor*)scene)->region.y2 = allocation->height;
 
-	// Optimise drawing by telling the canvas which area is visible
-	wf_context_set_viewport(wfc, &(WfViewPort){0, 0, GL_WIDTH, allocation->height});
-
 	int i; for(i=0;i<G_N_ELEMENTS(a);i++)
 		if(a[i]) wf_actor_set_rect(a[i], &(WfRectangle){
 			0.0,
