@@ -1,14 +1,14 @@
-/**
-* +----------------------------------------------------------------------+
-* | This file is part of the Ayyi project. http://ayyi.org               |
-* | copyright (C) 2012-2020 Tim Orford <tim@orford.org>                  |
-* +----------------------------------------------------------------------+
-* | This program is free software; you can redistribute it and/or modify |
-* | it under the terms of the GNU General Public License version 3       |
-* | as published by the Free Software Foundation.                        |
-* +----------------------------------------------------------------------+
-*
-*/
+/*
+ +----------------------------------------------------------------------+
+ | This file is part of the Ayyi project. https://www.ayyi.org          |
+ | copyright (C) 2012-2025 Tim Orford <tim@orford.org>                  |
+ +----------------------------------------------------------------------+
+ | This program is free software; you can redistribute it and/or modify |
+ | it under the terms of the GNU General Public License version 3       |
+ | as published by the Free Software Foundation.                        |
+ +----------------------------------------------------------------------+
+ |
+ */
 
 #define NG_HASHTABLE
 #define MAX_BLOCKS_PER_TEXTURE 32 // gives a texture size of 128k (256k stereo)
@@ -37,7 +37,6 @@ typedef struct {
 	int         mmidx_max[N_LOD];
 	int         mmidx_min[N_LOD];
 	int         time_stamp;
-	AGlShader*  shader;
 } NGRenderer;
 
 
@@ -48,7 +47,7 @@ typedef struct {
 } HiResNGWaveform;
 
 
-static void ng_gl2_queue_clean(Renderer*);
+static void ng_gl2_queue_clean (Renderer*);
 
 
 static void
@@ -70,6 +69,13 @@ ng_gl2_set (Section* section, int pos, char val)
 	section->buffer[pos] = val;
 	return true;
 }
+static void
+ng_gl2_set_ (Section* section, int pos, char val)
+{
+	g_return_if_fail(section->buffer_size);
+	g_return_if_fail(pos < section->buffer_size);
+	section->buffer[pos] = val;
+}
 #else
 #define ng_gl2_set(section, pos, val) (section->buffer[pos] = val, true)
 #define ng_gl2_set_(section, pos, val) (section->buffer[pos] = val)
@@ -85,7 +91,7 @@ ng_gl2_load_block (Renderer* renderer, WaveformActor* actor, int b)
 
 	#define get_block_size(ACTOR) (modes[renderer->mode].texture_size * waveform_get_n_channels(ACTOR->waveform) * WF_PEAK_VALUES_PER_SAMPLE * ROWS_PER_PEAK_TYPE)
 
-	Section* add_section(Renderer* renderer, WaveformActor* actor, HiResNGWaveform* data, int s)
+	Section* add_section (Renderer* renderer, WaveformActor* actor, HiResNGWaveform* data, int s)
 	{
 		int block_size = get_block_size(actor);
 		int buffer_size = block_size * MIN(MAX_BLOCKS_PER_TEXTURE, waveform_get_n_audio_blocks(waveform) - s * MAX_BLOCKS_PER_TEXTURE);
@@ -135,7 +141,7 @@ ng_gl2_load_block (Renderer* renderer, WaveformActor* actor, int b)
 		}
 	}
 
-	inline void lo_peakbuf_to_texture(Renderer* renderer, WaveformActor* actor, int b, Section* section, int n_chans, int block_size)
+	inline void lo_peakbuf_to_texture (Renderer* renderer, WaveformActor* actor, int b, Section* section, int n_chans, int block_size)
 	{
 		// borders: source data is not blocked so borders need to be added here.
 
@@ -183,10 +189,13 @@ ng_gl2_load_block (Renderer* renderer, WaveformActor* actor, int b)
 		}
 	}
 
-	inline void med_peakbuf_to_texture(Renderer* renderer, WaveformActor* actor, int b, Section* section, int n_chans, int block_size)
+	inline void med_peakbuf_to_texture (Renderer* renderer, WaveformActor* actor, int b, Section* section, int n_chans, int block_size)
 	{
 		// borders: source data is not blocked so borders are added here.
 
+		g_return_if_fail(n_chans > -1);
+		g_return_if_fail(n_chans <= 2);
+
 		Waveform* waveform = actor->waveform;
 		WaveformPrivate* w = waveform->priv;
 		WfPeakBuf* peak = &w->peak;
@@ -222,7 +231,7 @@ ng_gl2_load_block (Renderer* renderer, WaveformActor* actor, int b)
 		}
 	}
 
-	inline void hi_audio_to_texture(Renderer* renderer, WaveformActor* actor, int b, Section* section, int n_chans, int block_size)
+	inline void hi_audio_to_texture (Renderer* renderer, WaveformActor* actor, int b, Section* section, int n_chans, int block_size)
 	{
 		// borders: Source data blocks are correctly sized but an offset needs to be added.
 		//          The left hand border is currently empty which is ok if there is no texture post-processing.
@@ -278,6 +287,13 @@ ng_gl2_load_block (Renderer* renderer, WaveformActor* actor, int b)
 #endif
 #endif
 	if(!*data){
+#ifdef DEBUG
+		if (!renderer->shader) {
+			static bool done = false;
+			if (!done) perr("renderer not initialised?");
+			done = true;
+		}
+#endif
 		int n_sections = waveform_get_n_audio_blocks(waveform) / MAX_BLOCKS_PER_TEXTURE + (waveform_get_n_audio_blocks(waveform) % MAX_BLOCKS_PER_TEXTURE ? 1 : 0);
 
 		*(*data = g_malloc0(sizeof(HiResNGWaveform) + sizeof(Section) * n_sections)) = (HiResNGWaveform){
@@ -330,7 +346,7 @@ ng_gl2_load_block (Renderer* renderer, WaveformActor* actor, int b)
 		}
 	}
 
-	int s; for(s=0;s<(*data)->size;s++){
+	for(int s=0;s<(*data)->size;s++){
 		Section* section = &(*data)->section[s];
 		if(!section->completed){
 			if(texture_changed[s]){
@@ -341,13 +357,13 @@ ng_gl2_load_block (Renderer* renderer, WaveformActor* actor, int b)
 
 				int width = modes[renderer->mode].texture_size;
 				int height = section->buffer_size / width;
-				int pixel_format = GL_ALPHA;
-				glBindTexture  (GL_TEXTURE_2D, section->texture);
+				#define pixel_format GL_ALPHA
+				agl_use_texture (section->texture);
 				glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_NEAREST);
 				glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_NEAREST);
 				// TODO it is quite common for this to be done several times in quick succession for the same texture with consecutive calls to ng_gl2_load_block
 				dbg(1, "%i: uploading texture: %i x %i", s, width, height);
-				glTexImage2D(GL_TEXTURE_2D, 0, GL_ALPHA, width, height, 0, pixel_format, GL_UNSIGNED_BYTE, section->buffer);
+				glTexImage2D(GL_TEXTURE_2D, 0, GL_RGBA8, width, height, 0, pixel_format, GL_UNSIGNED_BYTE, section->buffer);
 				gl_warn("error binding texture: %u", section->texture);
 			}
 
@@ -363,17 +379,17 @@ ng_gl2_load_block (Renderer* renderer, WaveformActor* actor, int b)
  *  This is done only once per paint, it does not have to be done per block
  */
 static bool
-ng_gl2_pre_render (Renderer* renderer, WaveformActor* actor)
+ng_pre_render (Renderer* renderer, WaveformActor* actor)
 {
 	Waveform* w = actor->waveform;
 	WfActorPriv* _a = actor->priv;
 	RenderInfo* r = &_a->render_info;
 
-	if(r->mode >= MODE_V_HI) return false; // TODO this will happen when falling through.
+	if (r->mode >= MODE_V_HI) return false; // TODO this will happen when falling through.
 
 	HiResNGWaveform* data = (HiResNGWaveform*)w->priv->render_data[renderer->mode];
-	HiResNGShader* shader = (HiResNGShader*)((NGRenderer*)renderer)->shader;
-	if(!data || !shader) return false; // this can happen when we fall through from v hi res.
+	HiResNGShader* shader = (HiResNGShader*)renderer->shader;
+	if (!data || !shader) return false; // this can happen when we fall through from v hi res.
 
 	shader->uniform.fg_colour = (((AGlActor*)actor)->colour & 0xffffff00) + (unsigned)(0xff * _a->opacity);
 	shader->uniform.top = r->rect.top;
@@ -403,7 +419,15 @@ ng_gl2_pre_render (Renderer* renderer, WaveformActor* actor)
 					: 3
 		);
 
-	agl_use_program(&shader->shader);
+	agl_scale (&shader->shader, 1., 1.);
+	agl_translate (&shader->shader, -((AGlActor*)actor)->scrollable.x1, 0.);
+	shader->shader.set_uniforms_((AGlShader*)shader);
+
+	glActiveTexture (GL_TEXTURE0);
+	glBindBuffer (GL_ARRAY_BUFFER, agl->vbo);
+
+	glEnableVertexAttribArray (0);
+	glVertexAttribPointer (0, 4, GL_FLOAT, GL_FALSE, 4 * sizeof(float), (void*)0);
 
 	return true;
 }
@@ -418,7 +442,7 @@ ng_gl2_render_block (Renderer* renderer, WaveformActor* actor, int b, bool is_fi
 
 	Waveform* waveform = actor->waveform; 
 	WfActorPriv* _a = actor->priv;
-	RenderInfo* r  = &_a->render_info;
+	RenderInfo* r = &_a->render_info;
 
 	int  s = b / MAX_BLOCKS_PER_TEXTURE;
 	int _b = b % MAX_BLOCKS_PER_TEXTURE;
@@ -428,13 +452,11 @@ ng_gl2_render_block (Renderer* renderer, WaveformActor* actor, int b, bool is_fi
 	Section* section = &data->section[s];
 
 	if(!_b && b != r->viewport_blocks.first){
-		HiResNGShader* shader = (HiResNGShader*)((NGRenderer*)renderer)->shader;
+		HiResNGShader* shader = (HiResNGShader*)renderer->shader;
 		shader->uniform.tex_height = section->buffer_size / modes[renderer->mode].texture_size;
-		shader->shader.set_uniforms_(actor);
+		shader->shader.set_uniforms_((AGlShader*)shader);
 	}
 
-																								glActiveTexture(GL_TEXTURE0);
-
 	TextureRange tex;
 	WfSampleRegionf block;
 	if(!wf_actor_get_quad_dimensions(actor, b, is_first, is_last, x, &tex, &block.start, &block.len, border, 1)) return false;
@@ -445,19 +467,26 @@ ng_gl2_render_block (Renderer* renderer, WaveformActor* actor, int b, bool is_fi
 
 	//dbg(0, "b=%i %u n_rows=%f x=%f-->%f y=%f (%f)", b % MAX_BLOCKS_PER_TEXTURE, section->texture, n_rows, tex.start, tex.end, ty, ((float)(b % MAX_BLOCKS_PER_TEXTURE) * 4.0 * waveform->n_channels));
 
-	agl_textured_rect(section->texture, block.start, r->rect.top, block.len, r->rect.height, &tex_rect);
+	agl_textured_rect_fast (section->texture, block.start, r->rect.top, block.len, r->rect.height, &tex_rect);
 
 	return true;
 }
 
 
+static void
+ng_gl2_post_render (Renderer* renderer, WaveformActor* actor)
+{
+	glBindBuffer(GL_ARRAY_BUFFER, 0);  
+}
+
+
 static void
 ng_make_lod_levels (NGRenderer* renderer, Mode mode)
 {
 	int p = 0;
 	int width = modes[mode].texture_size;
 	int level_size = width;
-	int i; for(i=0;i<N_LOD;i++){
+	for (int i=0;i<N_LOD;i++){
 		renderer->mmidx_max[i] = p;
 		renderer->mmidx_min[i] = p + width * ROWS_PER_PEAK_TYPE;
 		level_size = width / (1 << i);
@@ -564,5 +593,3 @@ ng_gl2_queue_clean (Renderer* renderer)
 {
 	if(!idle_id) idle_id = g_idle_add_full(G_PRIORITY_LOW, __clean, renderer, NULL);
 }
-
-
