@@ -1,42 +1,41 @@
-/**
-* +----------------------------------------------------------------------+
-* | This file is part of the Ayyi project. http://ayyi.org               |
-* | copyright (C) 2012-2020 Tim Orford <tim@orford.org>                  |
-* +----------------------------------------------------------------------+
-* | This program is free software; you can redistribute it and/or modify |
-* | it under the terms of the GNU General Public License version 3       |
-* | as published by the Free Software Foundation.                        |
-* +----------------------------------------------------------------------+
-*
-*/
+/*
+ +----------------------------------------------------------------------+
+ | This file is part of the Ayyi project. https://www.ayyi.org          |
+ | copyright (C) 2012-2025 Tim Orford <tim@orford.org>                  |
+ +----------------------------------------------------------------------+
+ | This program is free software; you can redistribute it and/or modify |
+ | it under the terms of the GNU General Public License version 3       |
+ | as published by the Free Software Foundation.                        |
+ +----------------------------------------------------------------------+
+ |
+ */
+
 #ifndef __actor_c__
 #define __wf_private__
-#define __wf_canvas_priv__
 #include "config.h"
-#include <fcntl.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <math.h>
-#include <stdint.h>
 #include <sys/time.h>
 #include <sndfile.h>
 #include <gtk/gtk.h>
 #include <GL/gl.h>
 #include "waveform/waveform.h"
 
-extern int wf_debug;
 #endif // __actor_c__
 
-// needed for v_hi res. TODO check whether visual effect is good for gl1 hi_res.
-#define ANTIALIASED_LINES
+typedef struct
+{
+	Renderer       renderer;
+	WfSampleRegion block_region;
+} HiRenderer;
 
-#ifdef MULTILINE_SHADER
-static GLuint lines_texture[8] = {0};
-#endif
+#define ANTIALIASED_LINES
 
 #define RENDER_DATA_HI(W) ((WfTexturesHi*)W->render_data[MODE_HI])
 
+static inline bool calc_render_info (WaveformActor* actor);
+
+#ifdef DEBUG
 static void  _wf_actor_print_hires_textures  (WaveformActor*);
+#endif
 
 
 void
@@ -81,8 +80,12 @@ hi_free_gl1 (Renderer* renderer, Waveform* w)
 		if(w == a->waveform){ // the actor may have a new waveform and there is currently no way to cancel old requests.
 			modes[MODE_HI].renderer->load_block(modes[MODE_HI].renderer, a, b);
 
-			//TODO check this block is within current viewport
-			if(((AGlActor*)a)->root && ((AGlActor*)a)->root->draw) wf_canvas_queue_redraw(a->context);
+			RenderInfo* r = &a->priv->render_info;
+			if (!r->valid) calc_render_info(a);
+			BlockRange blocks = a->priv->render_info.viewport_blocks;
+			if (!r->valid || (b >= blocks.first && b <= blocks.last)) {
+				if(((AGlActor*)a)->root && ((AGlActor*)a)->root->draw) wf_context_queue_redraw(a->context);
+			}
 		}
 	}
 
@@ -93,56 +96,6 @@ hi_request_block (WaveformActor* a, int b)
 }
 
 
-#ifdef MULTILINE_SHADER
-GLuint
-_wf_create_lines_texture (guchar* pbuf, int width, int height)
-{
-	/*
-	 * This texture is used as data for the shader.
-	 * Each column represents a vertex.
-	 * Each row contains the following values:
-	 *   0: x value // .. or maybe not
-	 *   1: y value
-	 *
-	 */
-	glEnable(GL_TEXTURE_2D);
-
-	if(!lines_texture[0]){
-		glGenTextures(8, lines_texture);
-		if(glGetError() != GL_NO_ERROR){ gerr ("couldnt create lines_texture."); return 0; }
-		dbg(2, "lines_texture=%i", lines_texture[0]);
-	}
-
-	/*
-	int y; for(y=0;y<height/2;y++){
-		int x; for(x=0;x<width;x++){
-			y=0; *(pbuf + y * width + x) = 0x40;
-			y=1; *(pbuf + y * width + x) = 0xa0;
-			y=2; *(pbuf + y * width + x) = 0xff;
-			y=3; *(pbuf + y * width + x) = 0xa0;
-			y=4; *(pbuf + y * width + x) = 0x40;
-		}
-	}
-	*/
-
-	// currently we rotate through a fixed number of textures. TODO needs improvement - fixed number will either be too high or too low depending on the application.
-	static int t_idx = 0;
-	int t = t_idx;
-
-	int pixel_format = GL_ALPHA;
-	glBindTexture  (GL_TEXTURE_2D, lines_texture[t]);
-	glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_NEAREST);
-	glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_NEAREST);
-	glTexImage2D(GL_TEXTURE_2D, 0, GL_ALPHA, width, height, 0, pixel_format, GL_UNSIGNED_BYTE, pbuf);
-	gl_warn("error binding lines texture");
-
-	t_idx = (t_idx + 1) % 8;
-
-	return lines_texture[t];
-}
-#endif
-
-
 static void
 hi_gl1_load_block (Renderer* renderer, WaveformActor* a, int block)
 {
@@ -157,7 +110,7 @@ hi_gl1_load_block (Renderer* renderer, WaveformActor* a, int block)
 		int c = WF_LEFT;
 
 		if(glIsTexture(texture->t[c].main)){
-			gwarn("already assigned");
+			pwarn("already assigned");
 			return;
 		}
 
@@ -182,10 +135,12 @@ hi_gl1_load_block (Renderer* renderer, WaveformActor* a, int block)
 			wf_actor_allocate_block_hi(a, block);
 		}
 		else dbg(1, "b=%i: already have texture. t=%i", block, texture->t[WF_LEFT].main);
-		if(wf_debug > 1) _wf_actor_print_hires_textures(a);
+#ifdef DEBUG
+		if(_debug_ > 1) _wf_actor_print_hires_textures(a);
+#endif
 
 		//TODO check this block is within current viewport
-		if(((AGlActor*)a)->root->draw) wf_canvas_queue_redraw(a->context);
+		if(((AGlActor*)a)->root->draw) wf_context_queue_redraw(a->context);
 	}
 }
 
@@ -216,9 +171,9 @@ make_texture_data_hi(Waveform* w, int ch, IntBufHi* buf, int blocknum)
 }
 
 
-#ifdef VERTEX_ARRAYS
+#if 0
 static void
-_draw_line(int x1, int y1, int x2, int y2, float r, float g, float b, float a)
+_draw_line (int x1, int y1, int x2, int y2, float r, float g, float b, float a)
 {
 	glColor4f(r, g, b, a);
 #ifdef ANTIALIASED_LINES
@@ -245,7 +200,7 @@ _draw_line(int x1, int y1, int x2, int y2, float r, float g, float b, float a)
 
 #if 0
 static void
-_draw_line_f(float x1, int y1, float x2, int y2, float r, float g, float b, float a)
+_draw_line_f (float x1, int y1, float x2, int y2, float r, float g, float b, float a)
 {
 	glLineWidth(1);
 	glColor4f(r, g, b, a);
@@ -356,11 +311,11 @@ draw_wave_buffer_hi_gl1 (Renderer* renderer, WaveformActor* actor, int b, bool i
 
 		/*
 		if(!(region_end / io_ratio <= peakbuf->size / WF_PEAK_VALUES_PER_SAMPLE))
-			gwarn("end/ratio=%i size=%i - region.end should never exceed %i", ((int)region_end / io_ratio), peakbuf->size / WF_PEAK_VALUES_PER_SAMPLE, io_ratio * peakbuf->size / WF_PEAK_VALUES_PER_SAMPLE);
+			pwarn("end/ratio=%i size=%i - region.end should never exceed %i", ((int)region_end / io_ratio), peakbuf->size / WF_PEAK_VALUES_PER_SAMPLE, io_ratio * peakbuf->size / WF_PEAK_VALUES_PER_SAMPLE);
 		*/
 		g_return_if_fail(region_end / io_ratio <= peakbuf->size / WF_PEAK_VALUES_PER_SAMPLE);
 		while (p < region.len / io_ratio){
-										if(2 * p_ >= peakbuf->size) gwarn("s_=%i size=%i", p_, peakbuf->size);
+										if(2 * p_ >= peakbuf->size) pwarn("s_=%i size=%i", p_, peakbuf->size);
 										g_return_if_fail(2 * p_ < peakbuf->size);
 			x = rect->left + (((double)p) / ((double)region.len)) * rect->len * io_ratio;
 			if (x - rect->left >= rect->len) break;
@@ -505,7 +460,7 @@ wf_actor_get_quad_dimensions (WaveformActor* actor, int b, bool is_first, bool i
 			double distance_from_file_start_to_region_end = region_px.start + MIN(r->rect.len, region_px.len);
 			block_wid = distance_from_file_start_to_region_end - b * r->block_wid;
 			dbg(2, " %i: inset=%.2f s->e=%.2f i*b=%.2f", b, region_px.start, distance_from_file_start_to_region_end, b * r->block_wid);
-			if(b * r->block_wid > distance_from_file_start_to_region_end){ gwarn("!!"); return false; }
+			if(b * r->block_wid > distance_from_file_start_to_region_end){ pwarn("!!"); return false; }
 			block_wid = MIN(r->rect.len, block_wid);
 #else
 			WfdRange block_px = {
@@ -531,7 +486,7 @@ wf_actor_get_quad_dimensions (WaveformActor* actor, int b, bool is_first, bool i
 if(tex_pct > usable_pct || tex_pct < 0.0){
 dbg (0, "%i: is_first=%i is_last=%i x=%.2f wid=%.2f/%.2f tex_pct=%.3f tex_start=%.3f", b, is_first, is_last, x, block_wid, r->block_wid, tex_pct, tex_start);
 }
-	if(tex_pct - 0.0001 > usable_pct || tex_pct < 0.0) gwarn("tex_pct > %.3f! %.3f (b=%i) %.3f --> %.3f", usable_pct, tex_pct, b, tex_start, tex_start + tex_pct);
+	if(tex_pct - 0.0001 > usable_pct || tex_pct < 0.0) pwarn("tex_pct > %.3f! %.3f (b=%i) %.3f --> %.3f", usable_pct, tex_pct, b, tex_start, tex_start + tex_pct);
 	tex_x = x + ((is_first && r->first_offset) ? r->first_offset_px : 0);
 
 	*tex = (TextureRange){tex_start, tex_start + tex_pct};
@@ -625,10 +580,12 @@ hi_gl1_render_block (Renderer* renderer, WaveformActor* actor, int b, gboolean i
 #endif
 
 
+#ifdef DEBUG
 static void
 _wf_actor_print_hires_textures (WaveformActor* a)
 {
-	dbg(0, "");
+	PF0;
+
 	GHashTableIter iter;
 	gpointer key, value;
 	g_hash_table_iter_init (&iter, RENDER_DATA_HI(a->waveform->priv)->textures);
@@ -638,9 +595,10 @@ _wf_actor_print_hires_textures (WaveformActor* a)
 		printf("  b=%i t=%i\n", b, th->t[WF_LEFT].main);
 	}
 }
+#endif
 
 
-NGRenderer hi_renderer_gl2 = {{MODE_HI, hi_gl2_new, ng_gl2_load_block, ng_gl2_pre_render, ng_gl2_render_block, ng_gl2_free_waveform}};
+NGRenderer hi_renderer_gl2 = {{MODE_HI, hi_gl2_init, ng_gl2_load_block, ng_pre_render, ng_gl2_render_block, ng_gl2_post_render, ng_gl2_free_waveform}};
 
 HiRenderer hi_renderer_gl1 = {{MODE_HI, hi_new_gl1, hi_gl1_load_block, hi_gl1_pre_render,
 #ifdef HIRES_NONSHADER_TEXTURES
@@ -649,7 +607,7 @@ HiRenderer hi_renderer_gl1 = {{MODE_HI, hi_new_gl1, hi_gl1_load_block, hi_gl1_pr
 				// without shaders, each sample line is drawn directly without using textures, so performance will be relatively poor.
 				draw_wave_buffer_hi_gl1,
 #endif
-				hi_free_gl1
+				NULL, hi_free_gl1
 }};
 
 
