@@ -1,20 +1,23 @@
-/**
-* +----------------------------------------------------------------------+
-* | This file is part of the Ayyi project. http://ayyi.org               |
-* | copyright (C) 2012-2020 Tim Orford <tim@orford.org>                  |
-* +----------------------------------------------------------------------+
-* | This program is free software; you can redistribute it and/or modify |
-* | it under the terms of the GNU General Public License version 3       |
-* | as published by the Free Software Foundation.                        |
-* +----------------------------------------------------------------------+
-*
-*/
+/*
+ +----------------------------------------------------------------------+
+ | This file is part of the Ayyi project. https://www.ayyi.org          |
+ | copyright (C) 2012-2025 Tim Orford <tim@orford.org>                  |
+ +----------------------------------------------------------------------+
+ | This program is free software; you can redistribute it and/or modify |
+ | it under the terms of the GNU General Public License version 3       |
+ | as published by the Free Software Foundation.                        |
+ +----------------------------------------------------------------------+
+ |
+ */
+
 #define __waveform_peak_c__
 #define __wf_private__
 #include "config.h"
 #include <fcntl.h>
 #include <sys/stat.h>
+#ifdef USE_SNDFILE
 #include <sndfile.h>
+#endif
 #include <glib.h>
 #include "inttypes.h"
 #include "decoder/ad.h"
@@ -69,6 +72,11 @@ waveform_load_new(const char* filename)
 }
 
 
+/**
+ *  waveform_new
+ *
+ *  Returns: waveform
+ */
 Waveform*
 waveform_new (const char* filename)
 {
@@ -135,16 +143,24 @@ waveform_finalize (GObject* obj)
 		if(_w->peak.buf[c]) g_free(_w->peak.buf[c]);
 	}
 
+	if(_w->peaks){
+		if(!_w->peaks->is_resolved){
+			// allow subscribers to free closure data
+			am_promise_fail(_w->peaks, NULL);
+		}
+		am_promise_unref0(_w->peaks);
+	}
+
 	if(_w->hires_peaks){
 		void** data = _w->hires_peaks->pdata;
-		int i; for(i=0;i<_w->hires_peaks->len;i++){
+		for(int i=0;i<_w->hires_peaks->len;i++){
 			Peakbuf* p = data[i];
 			waveform_peakbuf_free(p);
 		}
-		g_ptr_array_free (_w->hires_peaks, false);
+		g_ptr_array_free (_w->hires_peaks, true);
 	}
 
-	int m; for(m=MODE_V_LOW;m<=MODE_HI;m++){
+	for(int m=MODE_V_LOW;m<=MODE_HI;m++){
 		if(_w->render_data[m]) pwarn("actor data not cleared");
 	}
 
@@ -177,7 +193,7 @@ _waveform_get_property (GObject* object, guint property_id, GValue* value, GPara
 		gpointer user_data;
 	} C;
 
-	static void waveform_load_done(gpointer waveform, gpointer _c)
+	static void waveform_load_done (gpointer waveform, gpointer _c)
 	{
 		C* c = _c;
 		if(c->callback) c->callback((Waveform*)waveform, ((Waveform*)waveform)->priv->peaks->error, c->user_data);
@@ -209,10 +225,18 @@ _waveform_get_property (GObject* object, guint property_id, GValue* value, GPara
  *  Load the peakdata for a waveform, and create a cached peakfile if not already existing.
  */
 void
-waveform_load(Waveform* w, WfCallback3 callback, gpointer user_data)
+waveform_load (Waveform* w, WfCallback3 callback, gpointer user_data)
 {
 	WaveformPrivate* _w = w->priv;
 
+	if(g_strrstr(w->filename, "%L")){
+		char rhs[256] = {0};
+		waveform_get_rhs(w->filename, rhs);
+		if(g_file_test(rhs, G_FILE_TEST_EXISTS)){
+			w->n_channels = 2;
+		}
+	}
+
 	if(!_w->peaks){
 		_w->peaks = am_promise_new(w);
 	}
@@ -263,26 +287,27 @@ waveform_get_sf_data(Waveform* w)
 	if(w->offline) return;
 
 	WfDecoder d = {{0,}};
-	if(ad_open(&d, w->filename)){
+	if (ad_open(&d, w->filename)) {
 		w->n_frames = d.info.frames; // for some filetypes this will be an estimate
 		w->n_channels = w->n_channels ? w->n_channels : d.info.channels; // file info is not correct in the case of split stereo files.
 		w->samplerate = d.info.sample_rate;
 
-		ad_close(&d);
-		ad_free_nfo(&d.info);
-	}else{
+		ad_clear(&d);
+	} else {
 		w->offline = true;
 
-		if(!g_file_test(w->filename, G_FILE_TEST_EXISTS)){
+		if (!g_file_test(w->filename, G_FILE_TEST_EXISTS)) {
 			if(wf_debug) pwarn("file open failure. no such file: %s", w->filename);
-		}else{
+		} else {
+#ifdef USE_SNDFILE
 			if(wf_debug) g_warning("file open failure (%s) \"%s\"\n", sf_strerror(NULL), w->filename);
+#endif
 
 			// attempt to work with only a pre-existing peakfile in case file is temporarily unmounted
 			if(waveform_load_sync(w)){
 				w->n_channels = _w->peak.buf[1] ? 2 : 1;
 				w->n_frames = _w->num_peaks * WF_PEAK_RATIO;
-				dbg(1, "offline, have peakfile: n_frames=%Lu c=%i", w->n_frames, w->n_channels);
+				dbg(1, "offline, have peakfile: n_frames=%"PRIi64" c=%i", w->n_frames, w->n_channels);
 				return;
 			}
 		}
@@ -291,7 +316,11 @@ waveform_get_sf_data(Waveform* w)
 	if(_w->num_peaks && !CHECKS_DONE(w)){
 		if(w->n_frames > _w->num_peaks * WF_PEAK_RATIO){
 			char* peakfile = waveform_ensure_peakfile__sync(w);
-			pwarn("peakfile is too short. maybe corrupted. len=%i expected=%"PRIi64" '%s'", _w->num_peaks, w->n_frames / WF_PEAK_RATIO, peakfile);
+
+			int diff0 = w->n_frames - _w->num_peaks * WF_PEAK_RATIO;
+			int diff = diff0 / WF_PEAK_RATIO + (diff0 % WF_PEAK_RATIO ? 1 : 0);
+			pwarn("peakfile is too short. maybe corrupted. len=%i expected=%"PRIi64" (short by %i) '%s'", _w->num_peaks, w->n_frames / WF_PEAK_RATIO + (diff0 % WF_PEAK_RATIO ? 1 : 0), diff, peakfile);
+
 			w->renderable = false;
 			g_free(peakfile);
 		}
@@ -309,13 +338,14 @@ waveform_get_n_frames(Waveform* w)
 }
 
 
+/*
+ *  libwaveform can only handle mono or stereo files,
+ *  so this will never return > 2 even if the file is
+ *  multichannel.
+ */
 int
-waveform_get_n_channels(Waveform* w)
+waveform_get_n_channels (Waveform* w)
 {
-	// libwaveform can only handle mono or stereo files,
-	// so this will never return > 2 even if the file is
-	// multichannel.
-
 	g_return_val_if_fail(w, 0);
 
 	if(w->n_frames) return MIN(2, w->n_channels);
@@ -372,7 +402,14 @@ waveform_load_peak (Waveform* w, const char* peak_file, int ch_num)
 		if(wf_debug > -1 && w->n_frames){
 			uint64_t a = _w->num_peaks;
 			uint64_t b = w->n_frames / WF_PEAK_RATIO + (w->n_frames % WF_PEAK_RATIO ? 1 : 0);
-			if(a != b) pwarn("got %"PRIi64" peaks, expected %"PRIi64, a, b);
+			if(a != b){
+				pwarn("got %"PRIi64" peaks, expected %"PRIi64, a, b);
+				printf("\tn_frames=%i\n", (int)w->n_frames);
+				printf("\tn_frames/WF_PEAK_RATIO=%i\n", (int)(w->n_frames / WF_PEAK_RATIO));
+				printf("\tn_channels=%i\n", (int)w->n_channels);
+				printf("\tpeak_file=%s\n", peak_file);
+				printf("\texpected_peakfile_size=%i bytes\n", (int)((((int)w->n_frames) / WF_PEAK_RATIO) * w->n_channels * WF_PEAK_VALUES_PER_SAMPLE * sizeof(short)));
+			}
 		}
 	}
 #endif
@@ -511,9 +548,10 @@ fullpath = g_strdup(src); //TODO
 	struct stat sinfo;
 	if(stat(rms_file, &sinfo)){ pwarn ("rms file stat error. '%s'", rms_file); close(fp); goto out; }
 	off_t fsize = sinfo.st_size;
-	rb = g_new0(RmsBuf, 1);
-	rb->size = fsize;
-	rb->buf = g_new(char, fsize);
+	rb = WF_NEW(RmsBuf,
+		.size = fsize,
+		.buf = g_new(char, fsize)
+	);
 
 	//read the whole peak file into memory:
 	if(read(fp, rb->buf, fsize) != fsize) perr ("read error. couldnt read %"PRIi64" bytes from %s", fsize, rms_file);
@@ -582,11 +620,10 @@ waveform_get_peakbuf_n(Waveform* w, int block_num)
 
 	GPtrArray* peaks = w->priv->hires_peaks;
 	g_return_val_if_fail(peaks, NULL);
-	Peakbuf* peakbuf = NULL;
-	if(block_num >= peaks->len){
-	}else{
-		peakbuf = g_ptr_array_index(peaks, block_num);
-	}
+	g_return_val_if_fail(block_num < peaks->len, NULL);
+
+	Peakbuf* peakbuf = g_ptr_array_index(peaks, block_num);
+
 	dbg(2, "block_num=%i peaks->len=%i", block_num, peaks->len);
 
 	return peakbuf;
@@ -594,7 +631,7 @@ waveform_get_peakbuf_n(Waveform* w, int block_num)
 
 
 void
-waveform_peakbuf_assign(Waveform* w, int block_num, Peakbuf* peakbuf)
+waveform_peakbuf_assign (Waveform* w, int block_num, Peakbuf* peakbuf)
 {
 	g_return_if_fail(peakbuf);
 	g_return_if_fail(block_num >= 0);
@@ -609,19 +646,16 @@ waveform_peakbuf_assign(Waveform* w, int block_num, Peakbuf* peakbuf)
 
 
 int
-waveform_get_n_audio_blocks(Waveform* w)
+waveform_get_n_audio_blocks (Waveform* w)
 {
 	WfAudioData* audio = &w->priv->audio;
-	if(!audio->n_blocks){
+	if (!audio->n_blocks) {
 		uint64_t n_frames = waveform_get_n_frames(w);
 
 		int xtra = (n_frames % WF_SAMPLES_PER_TEXTURE) ? 1 : 0;
 		audio->n_blocks = n_frames / WF_SAMPLES_PER_TEXTURE + xtra; // WF_SAMPLES_PER_TEXTURE takes border into account
 
-		dbg(1, "setting samplecount=%Li xtra=%i n_blocks=%i",
-		        n_frames,
-		        xtra,
-		        audio->n_blocks);
+		dbg(1, "setting samplecount=%"PRIi64" xtra=%i n_blocks=%i", n_frames, xtra, audio->n_blocks);
 	}
 	return audio->n_blocks;
 }
@@ -647,6 +681,18 @@ waveform_find_max_audio_level(Waveform* w)
 }
 
 
+/*
+ *  Given a filename containing "%L", put the corresponding RHS filename into arg 2
+ */
+void
+waveform_get_rhs (const char* left, char* rhs)
+{
+	g_strlcpy(rhs, left, 256);
+	char* pos = g_strrstr(rhs, "%L") + 1;
+	*pos = 'R';
+}
+
+
 #if 0
 void
 waveform_print_blocks(Waveform* w)
