@@ -1,16 +1,15 @@
-/**
-* +----------------------------------------------------------------------+
-* | This file is part of Samplecat. http://ayyi.github.io/samplecat/     |
-* | copyright (C) 2007-2020 Tim Orford <tim@orford.org>                  |
-* +----------------------------------------------------------------------+
-* | This program is free software; you can redistribute it and/or modify |
-* | it under the terms of the GNU General Public License version 3       |
-* | as published by the Free Software Foundation.                        |
-* +----------------------------------------------------------------------+
-*
-* This file is partially based on vala/application.vala but is manually synced.
-*
-*/
+/*
+ +----------------------------------------------------------------------+
+ | This file is part of Samplecat. https://ayyi.github.io/samplecat/    |
+ | copyright (C) 2007-2025 Tim Orford <tim@orford.org>                  |
+ +----------------------------------------------------------------------+
+ | This program is free software; you can redistribute it and/or modify |
+ | it under the terms of the GNU General Public License version 3       |
+ | as published by the Free Software Foundation.                        |
+ +----------------------------------------------------------------------+
+ |
+ */
+
 #include "config.h"
 #include <string.h>
 #pragma GCC diagnostic ignored "-Wdeprecated-declarations"
@@ -101,12 +100,12 @@ application_new ()
 		ctx->options[CONFIG_ICON_THEME] = config_option_new_string("icon_theme", get_theme_name);
 	}
 
-	void on_filter_changed (Observable* filter, AMVal value, gpointer user_data)
+	void on_filter_changed (Observable* filter, AGlVal value, gpointer user_data)
 	{
 		application_search();
 	}
 	for(int i = 0; i < N_FILTERS; i++){
-		observable_subscribe(samplecat.model->filters3[i], on_filter_changed, NULL);
+		agl_observable_subscribe (samplecat.model->filters3[i], on_filter_changed, NULL);
 	}
 
 	application_set_auditioner(app);
@@ -138,9 +137,9 @@ application_free (Application* self)
 	ConfigContext* ctx = &app->configctx;
 	int i = 0;
 	ConfigOption* option;
-	while((option = ctx->options[i++])){
+	while ((option = ctx->options[i++])) {
 		g_value_unset(&option->val);
-		g_free(option);
+		g_clear_pointer(&ctx->options[i-1], g_free);
 	}
 }
 #endif
@@ -204,7 +203,7 @@ GType
 application_get_type ()
 {
 	static volatile gsize application_type_id__volatile = 0;
-	if (g_once_init_enter (&application_type_id__volatile)) {
+	if (g_once_init_enter ((gsize*)&application_type_id__volatile)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ApplicationClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) application_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (Application), 0, (GInstanceInitFunc) application_instance_init, NULL };
 		GType application_type_id;
 		application_type_id = g_type_register_static (G_TYPE_OBJECT, "Application", &g_define_type_info, 0);
@@ -297,52 +296,53 @@ application_set_ready()
 static int  auditioner_nullC() {return 0;}
 static void auditioner_null() {;}
 static bool auditioner_nullS(Sample* s) {return true;}
+static void auditioner_null_connect(ErrorCallback e, gpointer data){}
 
 static void
 _set_auditioner ()
 {
-	if(!app->no_gui) printf("auditioner: "); fflush(stdout);
+	if (!app->no_gui) { printf("auditioner: "); fflush(stdout); }
 
 	const static Auditioner a_null = {
 		&auditioner_nullC,
-		&auditioner_null,
+		&auditioner_null_connect,
 		&auditioner_null,
 		&auditioner_nullS,
 		NULL,
 		&auditioner_null,
-		NULL, NULL, NULL
+		NULL,
 	};
 
-	gboolean connected = false;
+	bool connected = false;
 #ifdef HAVE_JACK
-	if(!connected && can_use(app->players, "jack")){
+	if (!connected && can_use(app->players, "jack")) {
 		play->auditioner = & a_jack;
 		if (!play->auditioner->check()) {
 			connected = true;
-			printf("JACK playback.\n");
+			printf("JACK playback\n");
 		}
 	}
 #endif
 #ifdef HAVE_AYYIDBUS
-	if(!connected && can_use(app->players, "ayyi")){
+	if (!connected && can_use(app->players, "ayyi")) {
 		play->auditioner = & a_ayyidbus;
 		if (!play->auditioner->check()) {
 			connected = true;
-			if(!app->no_gui) printf("ayyi_audition.\n");
+			if (!app->no_gui) printf("ayyi_audition\n");
 		}
 	}
 #endif
 #ifdef HAVE_GPLAYER
-	if(!connected && can_use(app->players, "cli")){
+	if (!connected && can_use(app->players, "cli")) {
 		play->auditioner = & a_gplayer;
 		if (!play->auditioner->check()) {
 			connected = true;
-			printf("using CLI player.\n");
+			printf("using CLI player\n");
 		}
 	}
 #endif
 	if (!connected) {
-		printf("no playback support.\n");
+		printf("no playback support\n");
 		play->auditioner = & a_null;
 	}
 }
@@ -366,7 +366,7 @@ application_set_auditioner (Application* a)
 
 	gboolean set_auditioner_on_idle (gpointer data)
 	{
-		if(!((Application*)data)->no_gui){
+		if (!((Application*)data)->no_gui) {
 			_set_auditioner();
 
 			player_connect(set_auditioner_on_connected, data);
@@ -386,7 +386,7 @@ application_search()
 {
 	PF;
 
-	if(BACKEND_IS_NULL) return;
+	if (BACKEND_IS_NULL) return;
 
 	g_signal_emit_by_name(app, "search-starting");
 
@@ -394,14 +394,16 @@ application_search()
 }
 
 
+/*
+ *  Path must not contain trailing slash
+ */
 void
-application_scan(const char* path, ScanResults* results)
+application_scan (const char* path, ScanResults* results)
 {
-	// path must not contain trailing slash
-
 	g_return_if_fail(path);
 
 	app->state = SCANNING;
+	worker_go_slow = true;
 	statusbar_print(1, "scanning...");
 
 	application_add_dir(path, results);
@@ -409,9 +411,11 @@ application_scan(const char* path, ScanResults* results)
 	gchar* fail_msg = results->n_failed ? g_strdup_printf(", %i failed", results->n_failed) : "";
 	gchar* dupes_msg = results->n_dupes ? g_strdup_printf(", %i duplicates", results->n_dupes) : "";
 	statusbar_print(1, "add finished: %i files added%s%s", results->n_added, fail_msg, dupes_msg);
-	if(results->n_failed) g_free(fail_msg);
-	if(results->n_dupes) g_free(dupes_msg);
+	if (results->n_failed) g_free(fail_msg);
+	if (results->n_dupes) g_free(dupes_msg);
+
 	app->state = NONE;
+	worker_go_slow = false;
 }
 
 
@@ -419,14 +423,16 @@ application_scan(const char* path, ScanResults* results)
  *  uri must be "unescaped" before calling this fn. Method string must be removed.
  */
 bool
-application_add_file(const char* path, ScanResults* result)
+application_add_file (const char* path, ScanResults* result)
 {
+	if (BACKEND_IS_NULL) return false;
+
 	/* check if file already exists in the store
 	 * -> don't add it again
 	 */
-	if(samplecat.model->backend.file_exists(path, NULL)) {
-		if(!app->no_gui) statusbar_print(1, "duplicate: not re-adding a file already in db.");
-		g_warning("duplicate file: %s", path);
+	if (samplecat.model->backend.file_exists(path, NULL)) {
+		if (!app->no_gui) statusbar_print(1, "duplicate: %s", path);
+		if (_debug_) g_warning("duplicate file: %s", path);
 		Sample* s = sample_get_by_filename(path);
 		if (s) {
 			//sample_refresh(s, false);
@@ -439,23 +445,21 @@ application_add_file(const char* path, ScanResults* result)
 		return false;
 	}
 
-	if(!app->no_gui) dbg(1, "%s", path);
-
-	if(BACKEND_IS_NULL) return false;
+	if (!app->no_gui) dbg(1, "%s", path);
 
 	Sample* sample = sample_new_from_filename((char*)path, false);
 	if (!sample) {
 		if (app->state != SCANNING){
-			if (_debug_) gwarn("cannot add file: file-type is not supported");
+			if (_debug_) pwarn("cannot add file: file-type is not supported");
 			statusbar_print(1, "cannot add file: file-type is not supported");
 		}
 		return false;
 	}
 
-	if(_debug_ && app->no_gui){ printf("%s\n", path); fflush(stdout); }
+	if (_debug_ && app->no_gui) { printf("%s\n", path); fflush(stdout); }
 
-	if(!sample_get_file_info(sample)){
-		gwarn("cannot add file: reading file info failed. type=%s", sample->mimetype);
+	if (!sample_get_file_info(sample)) {
+		pwarn("cannot add file: reading file info failed. type=%s", sample->mimetype);
 		if(!app->no_gui) statusbar_print(1, "cannot add file: reading file info failed");
 		sample_unref(sample);
 		return false;
@@ -464,16 +468,16 @@ application_add_file(const char* path, ScanResults* result)
 #ifdef CHECK_SIMILAR
 	/* check if same file already exists with different path */
 	GList* existing;
-	if((existing = samplecat.model->backend.filter_by_audio(sample))) {
+	if ((existing = samplecat.model->backend.filter_by_audio(sample))) {
 		GList* l = existing; int i;
 #ifdef INTERACTIVE_IMPORT
 		GString* note = g_string_new("Similar or identical file(s) already present in database:\n");
 #endif
-		for(i=1;l;l=l->next, i++){
+		for (i=1;l;l=l->next, i++) {
 			/* TODO :prompt user: ask to delete one of the files
 			 * - import/update the remaining file(s)
 			 */
-			dbg(0, "found similar or identical file: %s", l->data);
+			dbg(1, "found similar or identical file: %s", (char*)l->data);
 #ifdef INTERACTIVE_IMPORT
 			if (i < 10)
 				g_string_append_printf(note, "%d: '%s'\n", i, (char*) l->data);
@@ -533,34 +537,34 @@ application_add_dir (const char* path, ScanResults* result)
 	GError* error = NULL;
 	GDir* dir;
 
-	if((dir = g_dir_open(path, 0, &error))){
-		while((file = g_dir_read_name(dir))){
-			if(file[0] == '.') continue;
+	if ((dir = g_dir_open(path, 0, &error))) {
+		while ((file = g_dir_read_name(dir))) {
+			if (file[0] == '.') continue;
 
 			snprintf(filepath, PATH_MAX, "%s%c%s", path, G_DIR_SEPARATOR, file);
 			filepath[PATH_MAX - 1] = '\0';
 			if (do_progress(0, 0)) break;
 
 			if(!g_file_test(filepath, G_FILE_TEST_IS_DIR)){
-				if(g_file_test(filepath, G_FILE_TEST_IS_SYMLINK) && !g_file_test(filepath, G_FILE_TEST_IS_REGULAR)){
+				if (g_file_test(filepath, G_FILE_TEST_IS_SYMLINK) && !g_file_test(filepath, G_FILE_TEST_IS_REGULAR)) {
 					dbg(0, "ignoring dangling symlink: %s", filepath);
-				}else{
-					if(application_add_file(filepath, result)){
-						if(!app->no_gui) statusbar_print(1, "%i files added", result->n_added);
+				} else {
+					if (application_add_file(filepath, result)) {
+						if (!app->no_gui) statusbar_print(1, "%i files added", result->n_added);
 					}
 				}
 			}
 			// IS_DIR
-			else if(app->config.add_recursive){
+			else if (app->config.add_recursive) {
 				application_add_dir(filepath, result);
 			}
 		}
 		//hide_progress(); ///no: keep window open until last recursion.
 		g_dir_close(dir);
-	}else{
+	} else {
 		result->n_failed++;
 
-		if(error->code == 2)
+		if (error->code == 2)
 			pwarn("%s\n", error->message); // permission denied
 		else
 			perr("cannot open directory. %i: %s\n", error->code, error->message);
@@ -570,35 +574,36 @@ application_add_dir (const char* path, ScanResults* result)
 
 
 void
-application_play(Sample* sample)
+application_play (Sample* sample)
 {
-	if(play->status == PLAY_PAUSED){
-		if(play->auditioner->playpause){
+	if (play->status == PLAY_PAUSED) {
+		if (play->auditioner->playpause) {
 			play->auditioner->playpause(false);
 		}
 		play->status = PLAY_PLAYING;
 		return;
 	}
 
-	if(sample) dbg(1, "%s", sample->name);
+	if (sample) dbg(1, "%s", sample->name);
 
-	if(player_play(sample)){
-		if(play->queue)
-			statusbar_print(1, "playing 1 of %i ...", g_list_length(play->queue));
+	if (player_play(sample)) {
+		if (play->queue)
+			statusbar_print(1, "playing 1 of %i ...", g_list_length(play->queue) + 1);
 		else
 			statusbar_print(1, "");
 #ifndef USE_GDL
-		if(app->view_options[SHOW_PLAYER].value) show_player(true);
+		if (app->view_options[SHOW_PLAYER].value) show_player(true);
 #endif
 
-	}else{
+	} else {
 		statusbar_print(1, "File not playable");
+		application_play_next();
 	}
 }
 
 
 void
-application_pause()
+application_pause ()
 {
 	if(play->auditioner->playpause){
 		play->auditioner->playpause(true);
@@ -608,7 +613,7 @@ application_pause()
 
 
 void
-application_play_selected()
+application_play_selected ()
 {
 	PF;
 	Sample* sample = samplecat.model->selection;
@@ -631,42 +636,43 @@ application_play_selected()
 void
 application_play_all ()
 {
-	if(play->queue){
+	if (play->queue) {
 		pwarn("already playing");
 		return;
 	}
 
-	gboolean foreach_func(GtkTreeModel* model, GtkTreePath* path, GtkTreeIter* iter, gpointer user_data)
+	gboolean foreach_func (GtkTreeModel* model, GtkTreePath* path, GtkTreeIter* iter, gpointer user_data)
 	{
-		//ADD_TO_QUEUE(samplecat_list_store_get_sample_by_path(path));
-		play->queue = g_list_append(play->queue, samplecat_list_store_get_sample_by_path(path)); // there is a ref already added, so another one is not needed when adding to the queue.
-		return G_SOURCE_CONTINUE;
+		// Not using ADD_TO_QUEUE as there is a ref already added, so another one is not needed when adding to the queue.
+		play->queue = g_list_append(play->queue, samplecat_list_store_get_sample_by_path(path));
+		return FALSE;
 	}
 	gtk_tree_model_foreach(GTK_TREE_MODEL(samplecat.store), foreach_func, NULL);
 
-	if(play->queue){
-		if(play->auditioner->play_all) play->auditioner->play_all(); // TODO remove this fn.
+	if (play->queue) {
+		if (play->auditioner->play_all)
+			play->auditioner->play_all(); // TODO remove this fn.
 		application_play_next();
 	}
 }
 
 
-void
+static void
 application_play_next ()
 {
 	PF;
-	if(play->queue){
+	if (play->queue) {
 		Sample* next = play->queue->data;
 		REMOVE_FROM_QUEUE(next);
 		dbg(1, "%s", next->full_path);
 
-		if(play->sample){
+		if (play->sample) {
 			play->position = UINT32_MAX;
 			g_signal_emit_by_name (play, "position");
 		}
 
 		application_play(next);
-	}else{
+	} else {
 		dbg(1, "play_all finished.");
 		player_stop();
 	}
@@ -676,12 +682,14 @@ application_play_next ()
 void
 application_play_path (const char* path)
 {
-	if(play->sample) player_stop();
+	if (play->sample) player_stop();
 
 	Sample* s = sample_new_from_filename((char*)path, false);
 	g_assert(s->ref_count == 1); // will be unreffed and freed in application_on_play_finished()
-	if(s){
-		application_play(s);
+	if (s) {
+		if (sample_get_file_info(s)) {
+			application_play(s);
+		}
 	}
 }
 
