@@ -1,14 +1,15 @@
-/**
-* +----------------------------------------------------------------------+
-* | This file is part of Samplecat. http://ayyi.github.io/samplecat/     |
-* | copyright (C) 2007-2020 Tim Orford <tim@orford.org>                  |
-* +----------------------------------------------------------------------+
-* | This program is free software; you can redistribute it and/or modify |
-* | it under the terms of the GNU General Public License version 3       |
-* | as published by the Free Software Foundation.                        |
-* +----------------------------------------------------------------------+
-*
-*/
+/*
+ +----------------------------------------------------------------------+
+ | This file is part of Samplecat. http://ayyi.github.io/samplecat/     |
+ | copyright (C) 2007-2021 Tim Orford <tim@orford.org>                  |
+ +----------------------------------------------------------------------+
+ | This program is free software; you can redistribute it and/or modify |
+ | it under the terms of the GNU General Public License version 3       |
+ | as published by the Free Software Foundation.                        |
+ +----------------------------------------------------------------------+
+ |
+ */
+
 #ifndef __listview_h__
 #define __listview_h__
 
@@ -32,7 +33,6 @@ struct _libraryview {
 };
 
 GtkWidget*  listview__new                  ();
-void        listview__show_db_missing      ();
 void        listview__add_item             ();
 
 void        listview__reset_colours        ();
@@ -41,5 +41,4 @@ void        listview__edit_row             (GtkWidget*, gpointer);
 void        listview__block_motion_handler ();
 gint        listview__get_mouseover_row    ();
 
-
 #endif
