@@ -11,33 +11,19 @@
 */
 
 #include "config.h"
-#include <getopt.h>
-#ifdef USE_GDL
-#include "gdl/gdl-dock-item.h"
-#endif
-#include "gdk/gdkkeysyms.h"
-#include "debug/debug.h"
-#include "icon_theme.h"
-#include "file_manager/pixmaps.h"
 #include "test/runner.h"
-#include "support.h"
-#include "panels/library.h"
 #include "application.h"
-#include "window.h"
 
-TestFn test_1, test_2;
-
-gpointer tests[] = {
-	test_1,
-	test_2,
-};
-
-int n_tests = G_N_ELEMENTS(tests);
+#include "utils.c"
+#include "list.c"
 
 
 void
 setup ()
 {
+	type_init();
+
+	TEST.n_tests = G_N_ELEMENTS(tests);
 }
 
 
@@ -46,16 +32,3 @@ teardown ()
 {
 }
 
-
-void
-test_1 ()
-{
-}
-
-
-void
-test_2 ()
-{
-}
-
-
